#define ITIMER_REAL 0
#define ITIMER_VIRTUAL 1
#define ITIMER_PROF 2
#define DST_NONE 0
#define DST_USA 1
#define DST_AUST 2
#define DST_WET 3
#define DST_MET 4
#define DST_EET 5
#define DST_CAN 6
#define CHILD_MAX 266
#define LINK_MAX 32767
#define MAX_CANON 1024
#define MAX_INPUT 1024
#define NAME_MAX 255
#define NGROUPS_MAX 16
#define OPEN_MAX 10240
#define PATH_MAX 1024
#define PIPE_BUF 512
#define BC_BASE_MAX 99
#define BC_DIM_MAX 2048
#define BC_SCALE_MAX 99
#define BC_STRING_MAX 1000
#define CHARCLASS_NAME_MAX 14
#define COLL_WEIGHTS_MAX 2
#define EQUIV_CLASS_MAX 2
#define EXPR_NEST_MAX 32
#define LINE_MAX 2048
#define RE_DUP_MAX 255
#define NZERO 0
#define GETNCNT 3
#define GETPID 4
#define GETVAL 5
#define GETALL 6
#define GETZCNT 7
#define SETVAL 8
#define SETALL 9
#define SEM_UNDO 0010000
#define SEM_A 00200
#define SEM_R 00400
#define PSEMNAMLEN 31
#define PSEM_NONE 1
#define PSEM_DEFINED 2
#define PSEM_ALLOCATED 4
#define PSEM_MAPPED 8
#define PSEM_INUSE 0x10
#define PSEM_REMOVED 0x20
#define PSEM_INCREATE 0x40
#define PSEM_INDELETE 0x80
#define FSOPT_NOFOLLOW 0x00000001
#define FSOPT_NOINMEMUPDATE 0x00000002
#define FSOPT_REPORT_FULLSIZE 0x00000004
#define FSOPT_PACK_INVAL_ATTRS 0x00000008
#define FSOPT_ATTR_CMN_EXTENDED 0x00000020
#define FSOPT_RETURN_REALDEV 0x00000200
#define FSOPT_NOFOLLOW_ANY 0x00000800
#define SEARCHFS_MAX_SEARCHPARMS 4096
#define ATTR_BIT_MAP_COUNT 5
#define VOL_CAPABILITIES_FORMAT 0
#define VOL_CAPABILITIES_INTERFACES 1
#define VOL_CAPABILITIES_RESERVED1 2
#define VOL_CAPABILITIES_RESERVED2 3
#define ATTR_MAX_BUFFER 8192
#define VOL_CAP_FMT_PERSISTENTOBJECTIDS 0x00000001
#define VOL_CAP_FMT_SYMBOLICLINKS 0x00000002
#define VOL_CAP_FMT_HARDLINKS 0x00000004
#define VOL_CAP_FMT_JOURNAL 0x00000008
#define VOL_CAP_FMT_JOURNAL_ACTIVE 0x00000010
#define VOL_CAP_FMT_NO_ROOT_TIMES 0x00000020
#define VOL_CAP_FMT_SPARSE_FILES 0x00000040
#define VOL_CAP_FMT_ZERO_RUNS 0x00000080
#define VOL_CAP_FMT_CASE_SENSITIVE 0x00000100
#define VOL_CAP_FMT_CASE_PRESERVING 0x00000200
#define VOL_CAP_FMT_FAST_STATFS 0x00000400
#define VOL_CAP_FMT_2TB_FILESIZE 0x00000800
#define VOL_CAP_FMT_OPENDENYMODES 0x00001000
#define VOL_CAP_FMT_HIDDEN_FILES 0x00002000
#define VOL_CAP_FMT_PATH_FROM_ID 0x00004000
#define VOL_CAP_FMT_NO_VOLUME_SIZES 0x00008000
#define VOL_CAP_FMT_DECMPFS_COMPRESSION 0x00010000
#define VOL_CAP_FMT_64BIT_OBJECT_IDS 0x00020000
#define VOL_CAP_FMT_DIR_HARDLINKS 0x00040000
#define VOL_CAP_FMT_DOCUMENT_ID 0x00080000
#define VOL_CAP_FMT_WRITE_GENERATION_COUNT 0x00100000
#define VOL_CAP_FMT_NO_IMMUTABLE_FILES 0x00200000
#define VOL_CAP_FMT_NO_PERMISSIONS 0x00400000
#define VOL_CAP_FMT_SHARED_SPACE 0x00800000
#define VOL_CAP_FMT_VOL_GROUPS 0x01000000
#define VOL_CAP_FMT_SEALED 0x02000000
#define VOL_CAP_FMT_CLONE_MAPPING 0x04000000
#define VOL_CAP_INT_SEARCHFS 0x00000001
#define VOL_CAP_INT_ATTRLIST 0x00000002
#define VOL_CAP_INT_NFSEXPORT 0x00000004
#define VOL_CAP_INT_READDIRATTR 0x00000008
#define VOL_CAP_INT_EXCHANGEDATA 0x00000010
#define VOL_CAP_INT_COPYFILE 0x00000020
#define VOL_CAP_INT_ALLOCATE 0x00000040
#define VOL_CAP_INT_VOL_RENAME 0x00000080
#define VOL_CAP_INT_ADVLOCK 0x00000100
#define VOL_CAP_INT_FLOCK 0x00000200
#define VOL_CAP_INT_EXTENDED_SECURITY 0x00000400
#define VOL_CAP_INT_USERACCESS 0x00000800
#define VOL_CAP_INT_MANLOCK 0x00001000
#define VOL_CAP_INT_NAMEDSTREAMS 0x00002000
#define VOL_CAP_INT_EXTENDED_ATTR 0x00004000
#define VOL_CAP_INT_CLONE 0x00010000
#define VOL_CAP_INT_SNAPSHOT 0x00020000
#define VOL_CAP_INT_RENAME_SWAP 0x00040000
#define VOL_CAP_INT_RENAME_EXCL 0x00080000
#define VOL_CAP_INT_RENAME_OPENFAIL 0x00100000
#define VOL_CAP_INT_RENAME_SECLUDE 0x00200000
#define VOL_CAP_INT_ATTRIBUTION_TAG 0x00400000
#define VOL_CAP_INT_PUNCHHOLE 0x00800000
#define ATTR_CMN_NAME 0x00000001
#define ATTR_CMN_DEVID 0x00000002
#define ATTR_CMN_FSID 0x00000004
#define ATTR_CMN_OBJTYPE 0x00000008
#define ATTR_CMN_OBJTAG 0x00000010
#define ATTR_CMN_OBJID 0x00000020
#define ATTR_CMN_OBJPERMANENTID 0x00000040
#define ATTR_CMN_PAROBJID 0x00000080
#define ATTR_CMN_SCRIPT 0x00000100
#define ATTR_CMN_CRTIME 0x00000200
#define ATTR_CMN_MODTIME 0x00000400
#define ATTR_CMN_CHGTIME 0x00000800
#define ATTR_CMN_ACCTIME 0x00001000
#define ATTR_CMN_BKUPTIME 0x00002000
#define ATTR_CMN_FNDRINFO 0x00004000
#define ATTR_CMN_OWNERID 0x00008000
#define ATTR_CMN_GRPID 0x00010000
#define ATTR_CMN_ACCESSMASK 0x00020000
#define ATTR_CMN_FLAGS 0x00040000
#define ATTR_CMN_GEN_COUNT 0x00080000
#define ATTR_CMN_DOCUMENT_ID 0x00100000
#define ATTR_CMN_USERACCESS 0x00200000
#define ATTR_CMN_EXTENDED_SECURITY 0x00400000
#define ATTR_CMN_UUID 0x00800000
#define ATTR_CMN_GRPUUID 0x01000000
#define ATTR_CMN_FILEID 0x02000000
#define ATTR_CMN_PARENTID 0x04000000
#define ATTR_CMN_FULLPATH 0x08000000
#define ATTR_CMN_ADDEDTIME 0x10000000
#define ATTR_CMN_ERROR 0x20000000
#define ATTR_CMN_DATA_PROTECT_FLAGS 0x40000000
#define ATTR_CMN_RETURNED_ATTRS 0x80000000
#define ATTR_CMN_VALIDMASK 0xFFFFFFFF
#define ATTR_CMN_SETMASK 0x51C7FF00
#define ATTR_CMN_VOLSETMASK 0x00006700
#define ATTR_VOL_FSTYPE 0x00000001
#define ATTR_VOL_SIGNATURE 0x00000002
#define ATTR_VOL_SIZE 0x00000004
#define ATTR_VOL_SPACEFREE 0x00000008
#define ATTR_VOL_SPACEAVAIL 0x00000010
#define ATTR_VOL_MINALLOCATION 0x00000020
#define ATTR_VOL_ALLOCATIONCLUMP 0x00000040
#define ATTR_VOL_IOBLOCKSIZE 0x00000080
#define ATTR_VOL_OBJCOUNT 0x00000100
#define ATTR_VOL_FILECOUNT 0x00000200
#define ATTR_VOL_DIRCOUNT 0x00000400
#define ATTR_VOL_MAXOBJCOUNT 0x00000800
#define ATTR_VOL_MOUNTPOINT 0x00001000
#define ATTR_VOL_NAME 0x00002000
#define ATTR_VOL_MOUNTFLAGS 0x00004000
#define ATTR_VOL_MOUNTEDDEVICE 0x00008000
#define ATTR_VOL_ENCODINGSUSED 0x00010000
#define ATTR_VOL_CAPABILITIES 0x00020000
#define ATTR_VOL_UUID 0x00040000
#define ATTR_VOL_FSTYPENAME 0x00100000
#define ATTR_VOL_FSSUBTYPE 0x00200000
#define ATTR_VOL_SPACEUSED 0x00800000
#define ATTR_VOL_QUOTA_SIZE 0x10000000
#define ATTR_VOL_RESERVED_SIZE 0x20000000
#define ATTR_VOL_ATTRIBUTES 0x40000000
#define ATTR_VOL_INFO 0x80000000
#define ATTR_VOL_VALIDMASK 0xF0B7FFFF
#define ATTR_VOL_SETMASK 0x80002000
#define ATTR_DIR_LINKCOUNT 0x00000001
#define ATTR_DIR_ENTRYCOUNT 0x00000002
#define ATTR_DIR_MOUNTSTATUS 0x00000004
#define ATTR_DIR_ALLOCSIZE 0x00000008
#define ATTR_DIR_IOBLOCKSIZE 0x00000010
#define ATTR_DIR_DATALENGTH 0x00000020
#define DIR_MNTSTATUS_MNTPOINT 0x00000001
#define DIR_MNTSTATUS_TRIGGER 0x00000002
#define ATTR_DIR_VALIDMASK 0x0000003f
#define ATTR_DIR_SETMASK 0x00000000
#define ATTR_FILE_LINKCOUNT 0x00000001
#define ATTR_FILE_TOTALSIZE 0x00000002
#define ATTR_FILE_ALLOCSIZE 0x00000004
#define ATTR_FILE_IOBLOCKSIZE 0x00000008
#define ATTR_FILE_DEVTYPE 0x00000020
#define ATTR_FILE_FORKCOUNT 0x00000080
#define ATTR_FILE_FORKLIST 0x00000100
#define ATTR_FILE_DATALENGTH 0x00000200
#define ATTR_FILE_DATAALLOCSIZE 0x00000400
#define ATTR_FILE_RSRCLENGTH 0x00001000
#define ATTR_FILE_RSRCALLOCSIZE 0x00002000
#define ATTR_FILE_VALIDMASK 0x000037FF
#define ATTR_FILE_SETMASK 0x00000020
#define ATTR_CMNEXT_RELPATH 0x00000004
#define ATTR_CMNEXT_PRIVATESIZE 0x00000008
#define ATTR_CMNEXT_LINKID 0x00000010
#define ATTR_CMNEXT_NOFIRMLINKPATH 0x00000020
#define ATTR_CMNEXT_REALDEVID 0x00000040
#define ATTR_CMNEXT_REALFSID 0x00000080
#define ATTR_CMNEXT_CLONEID 0x00000100
#define ATTR_CMNEXT_EXT_FLAGS 0x00000200
#define ATTR_CMNEXT_RECURSIVE_GENCOUNT 0x00000400
#define ATTR_CMNEXT_ATTRIBUTION_TAG 0x00000800
#define ATTR_CMNEXT_CLONE_REFCNT 0x00001000
#define ATTR_CMNEXT_VALIDMASK 0x00001ffc
#define ATTR_CMNEXT_SETMASK 0x00000000
#define ATTR_FORK_TOTALSIZE 0x00000001
#define ATTR_FORK_ALLOCSIZE 0x00000002
#define ATTR_FORK_RESERVED 0xffffffff
#define ATTR_FORK_VALIDMASK 0x00000003
#define ATTR_FORK_SETMASK 0x00000000
#define ATTR_CMN_NAMEDATTRCOUNT 0x00080000
#define ATTR_CMN_NAMEDATTRLIST 0x00100000
#define ATTR_FILE_CLUMPSIZE 0x00000010
#define ATTR_FILE_FILETYPE 0x00000040
#define ATTR_FILE_DATAEXTENTS 0x00000800
#define ATTR_FILE_RSRCEXTENTS 0x00004000
#define SRCHFS_START 0x00000001
#define SRCHFS_MATCHPARTIALNAMES 0x00000002
#define SRCHFS_MATCHDIRS 0x00000004
#define SRCHFS_MATCHFILES 0x00000008
#define SRCHFS_SKIPLINKS 0x00000010
#define SRCHFS_SKIPINVISIBLE 0x00000020
#define SRCHFS_SKIPPACKAGES 0x00000040
#define SRCHFS_SKIPINAPPROPRIATE 0x00000080
#define SRCHFS_NEGATEPARAMS 0x80000000
#define SRCHFS_VALIDOPTIONSMASK 0x800000FF
#define KEV_ANY_VENDOR 0
#define KEV_ANY_CLASS 0
#define KEV_ANY_SUBCLASS 0
#define KEV_VENDOR_APPLE 1
#define KEV_NETWORK_CLASS 1
#define KEV_IOKIT_CLASS 2
#define KEV_SYSTEM_CLASS 3
#define KEV_APPLESHARE_CLASS 4
#define KEV_FIREWALL_CLASS 5
#define KEV_IEEE80211_CLASS 6
#define KEV_NKE_CLASS 7
#define KEV_NKE_ALF_SUBCLASS 1
#define KEV_NKE_ALF_STATE_CHANGED 1
#define XNU_KERN_EVENT_DATA_SIZE 1
#define KEV_VENDOR_CODE_MAX_STR_LEN 200
#define N_KEV_VECTORS 5
#define M_WAITOK 0x0000
#define M_NOWAIT 0x0001
#define M_ZERO 0x0004
#define M_NULL 0x0008
#define M_PCB 4
#define M_RTABLE 5
#define M_IFADDR 9
#define M_SONAME 11
#define M_LOCKF 40
#define M_TEMP 80
#define M_UDFNODE 84
#define M_UDFMNT 85
#define M_KAUTH 100
#define HAVE_VT_LOCKERFS 1
#define VNODE_READ 0x01
#define VNODE_WRITE 0x02
#define VNODE_BLOCKMAP_NO_TRACK 0x04
#define VNODE_CLUSTER_VERIFY 0x08
#define PREALLOCATE 0x00000001
#define ALLOCATECONTIG 0x00000002
#define ALLOCATEALL 0x00000004
#define ALLOCATEPERSIST 0x00000008
#define ALLOCATEFROMPEOF 0x00000010
#define ALLOCATEFROMVOL 0x00000020
#define IO_UNIT 0x0001
#define IO_APPEND 0x0002
#define IO_SYNC 0x0004
#define IO_NODELOCKED 0x0008
#define IO_NDELAY 0x0010
#define IO_NOZEROFILL 0x0020
#define IO_TAILZEROFILL 0x0040
#define IO_HEADZEROFILL 0x0080
#define IO_NOZEROVALID 0x0100
#define IO_NOZERODIRTY 0x0200
#define IO_CLOSE 0x0400
#define IO_NOCACHE 0x0800
#define IO_RAOFF 0x1000
#define IO_DEFWRITE 0x2000
#define IO_PASSIVE 0x4000
#define IO_NOAUTH 0x8000
#define IO_NODIRECT 0x10000
#define IO_ENCRYPTED 0x20000
#define IO_RETURN_ON_THROTTLE 0x40000
#define IO_SINGLE_WRITER 0x80000
#define IO_SYSCALL_DISPATCH 0x100000
#define IO_SWAP_DISPATCH 0x200000
#define IO_SKIP_ENCRYPTION 0x400000
#define IO_EVTONLY 0x800000
#define IO_NOCACHE_SYSSPACE 0x1000000
#define IO_NOCACHE_SWRITE 0x2000000
#define LOOKUP 0
#define CREATE 1
#define DELETE 2
#define RENAME 3
#define OPMASK 3
#define FOLLOW 0x00000040
#define ISDOTDOT 0x00002000
#define MAKEENTRY 0x00004000
#define ISLASTCN 0x00008000
#define VNFS_NOCACHE 0x01
#define VNFS_CANTCACHE 0x02
#define VNFS_ADDFSREF 0x04
#define VNCREATE_FLAVOR 0
#define VA_UTIMES_NULL 0x010000
#define VA_EXCLUSIVE 0x020000
#define VA_NOINHERIT 0x040000
#define VA_NOAUTH 0x080000
#define VA_64BITOBJIDS 0x100000
#define VA_REALFSID 0x200000
#define VA_USEFSID 0x400000
#define VA_FILESEC_ACL 0x800000
#define VSUID 0x800
#define VSGID 0x400
#define VSVTX 0x200
#define VREAD 0x100
#define VWRITE 0x080
#define VEXEC 0x040
#define SKIPSYSTEM 0x0001
#define FORCECLOSE 0x0002
#define WRITECLOSE 0x0004
#define SKIPSWAP 0x0008
#define SKIPROOT 0x0010
#define DOCLOSE 0x0008
#define V_SAVE 0x0001
#define V_SAVEMETA 0x0002
#define REVOKEALL 0x0001
#define VNODE_REMOVE_NODELETEBUSY 0x0001
#define VNODE_REMOVE_SKIP_NAMESPACE_EVENT 0x0002
#define VNODE_REMOVE_NO_AUDIT_PATH 0x0004
#define VNODE_REMOVE_DATALESS_DIR 0x0008
#define VNODE_READDIR_EXTENDED 0x0001
#define VNODE_READDIR_REQSEEKOFF 0x0002
#define VNODE_READDIR_SEEKOFF32 0x0004
#define VNODE_READDIR_NAMEMAX 0x0008
#define VNODE_CLONEFILE_DEFAULT 0x0000
#define VNODE_CLONEFILE_NOOWNERCOPY 0x0001
#define VNODE_ASYNC_THROTTLE 15
#define VNODE_UPDATE_PARENT 0x01
#define VNODE_UPDATE_NAME 0x02
#define VNODE_UPDATE_CACHE 0x04
#define VNODE_UPDATE_PURGE 0x08
#define VNODE_LOOKUP_NOFOLLOW 0x01
#define VNODE_LOOKUP_NOCROSSMOUNT 0x02
#define VNODE_LOOKUP_CROSSMOUNTNOWAIT 0x04
#define VNODE_LOOKUP_NOFOLLOW_ANY 0x08
#define VNODE_RELOAD 0x01
#define VNODE_WAIT 0x02
#define VNODE_WRITEABLE 0x04
#define VNODE_WITHID 0x08
#define VNODE_NOLOCK_INTERNAL 0x10
#define VNODE_NODEAD 0x20
#define VNODE_NOSUSPEND 0x40
#define VNODE_ITERATE_ALL 0x80
#define VNODE_ITERATE_ACTIVE 0x100
#define VNODE_ITERATE_INACTIVE 0x200
#define VNODE_RETURNED 0
#define VNODE_RETURNED_DONE 1
#define VNODE_CLAIMED 2
#define VNODE_CLAIMED_DONE 3
#define IOCS_BUFFER_NUM_SIZE_BUCKETS 10
#define IOCS_BUFFER_MAX_BUCKET 9
#define IOCS_BUFFER_NUM_COMPRESSION_BUCKETS 7
#define IOCS_BLOCK_NUM_SIZE_BUCKETS 16
#define IOCS_SBE_PATH_LEN 128
#define IOCS_PATH_START_BYTES_TO_COPY 108
#define IOCS_PATH_END_BYTES_TO_COPY 20
#define IOCS_SYSCTL_LIVE 0x00000001
#define IOCS_SYSCTL_STORE_BUFFER_RD_ONLY 0x00000002
#define IOCS_SYSCTL_STORE_BUFFER_MARK 0x00000004
#define TANDEM 0x00000001
#define CBREAK 0x00000002
#define LCASE 0x00000004
#define ECHO 0x00000008
#define CRMOD 0x00000010
#define RAW 0x00000020
#define ODDP 0x00000040
#define EVENP 0x00000080
#define ANYP 0x000000c0
#define NLDELAY 0x00000300
#define TBDELAY 0x00000c00
#define XTABS 0x00000c00
#define CRDELAY 0x00003000
#define VTDELAY 0x00004000
#define BSDELAY 0x00008000
#define NL0 0x00000000
#define NL1 0x00000100
#define NL2 0x00000200
#define NL3 0x00000300
#define TAB0 0x00000000
#define TAB1 0x00000400
#define TAB2 0x00000800
#define CR0 0x00000000
#define CR1 0x00001000
#define CR2 0x00002000
#define CR3 0x00003000
#define FF0 0x00000000
#define FF1 0x00004000
#define BS0 0x00000000
#define BS1 0x00008000
#define CRTBS 0x00010000
#define PRTERA 0x00020000
#define CRTERA 0x00040000
#define TILDE 0x00080000
#define MDMBUF 0x00100000
#define LITOUT 0x00200000
#define TOSTOP 0x00400000
#define FLUSHO 0x00800000
#define NOHANG 0x01000000
#define L001000 0x02000000
#define CRTKIL 0x04000000
#define PASS8 0x08000000
#define CTLECH 0x10000000
#define PENDIN 0x20000000
#define DECCTQ 0x40000000
#define NOFLSH 0x80000000
#define OTTYDISC 0
#define NETLDISC 1
#define NTTYDISC 2
#define LOCKLEAF 0x0004
#define LOCKPARENT 0x0008
#define WANTPARENT 0x0010
#define UIO_MAXIOV 1024
#define UIO_SMALLIOV 8
#define EVFILT_SYSCOUNT 18
#define KEVENT_FLAG_NONE 0x000000
#define KEVENT_FLAG_IMMEDIATE 0x000001
#define KEVENT_FLAG_ERROR_EVENTS 0x000002
#define EV_ADD 0x0001
#define EV_DELETE 0x0002
#define EV_ENABLE 0x0004
#define EV_DISABLE 0x0008
#define EV_ONESHOT 0x0010
#define EV_CLEAR 0x0020
#define EV_RECEIPT 0x0040
#define EV_DISPATCH 0x0080
#define EV_UDATA_SPECIFIC 0x0100
#define EV_VANISHED 0x0200
#define EV_SYSFLAGS 0xF000
#define EV_FLAG0 0x1000
#define EV_FLAG1 0x2000
#define EV_EOF 0x8000
#define EV_ERROR 0x4000
#define NOTE_TRIGGER 0x01000000
#define NOTE_FFNOP 0x00000000
#define NOTE_FFAND 0x40000000
#define NOTE_FFOR 0x80000000
#define NOTE_FFCOPY 0xc0000000
#define NOTE_FFCTRLMASK 0xc0000000
#define NOTE_FFLAGSMASK 0x00ffffff
#define NOTE_LOWAT 0x00000001
#define NOTE_OOB 0x00000002
#define NOTE_DELETE 0x00000001
#define NOTE_WRITE 0x00000002
#define NOTE_EXTEND 0x00000004
#define NOTE_ATTRIB 0x00000008
#define NOTE_LINK 0x00000010
#define NOTE_RENAME 0x00000020
#define NOTE_REVOKE 0x00000040
#define NOTE_NONE 0x00000080
#define NOTE_FUNLOCK 0x00000100
#define NOTE_LEASE_DOWNGRADE 0x00000200
#define NOTE_LEASE_RELEASE 0x00000400
#define NOTE_EXIT 0x80000000
#define NOTE_FORK 0x40000000
#define NOTE_EXEC 0x20000000
#define NOTE_SIGNAL 0x08000000
#define NOTE_EXITSTATUS 0x04000000
#define NOTE_EXIT_DETAIL 0x02000000
#define NOTE_PDATAMASK 0x000fffff
#define NOTE_EXIT_DETAIL_MASK 0x00070000
#define NOTE_EXIT_DECRYPTFAIL 0x00010000
#define NOTE_EXIT_MEMORY 0x00020000
#define NOTE_EXIT_CSERROR 0x00040000
#define NOTE_VM_PRESSURE 0x80000000
#define NOTE_VM_PRESSURE_TERMINATE 0x40000000
#define NOTE_VM_PRESSURE_SUDDEN_TERMINATE 0x20000000
#define NOTE_VM_ERROR 0x10000000
#define NOTE_SECONDS 0x00000001
#define NOTE_USECONDS 0x00000002
#define NOTE_NSECONDS 0x00000004
#define NOTE_ABSOLUTE 0x00000008
#define NOTE_LEEWAY 0x00000010
#define NOTE_CRITICAL 0x00000020
#define NOTE_BACKGROUND 0x00000040
#define NOTE_MACH_CONTINUOUS_TIME 0x00000080
#define NOTE_MACHTIME 0x00000100
#define NOTE_TRACK 0x00000001
#define NOTE_TRACKERR 0x00000002
#define NOTE_CHILD 0x00000004
#define VMADDR_CID_HYPERVISOR 0
#define VMADDR_CID_RESERVED 1
#define VMADDR_CID_HOST 2
#define IMG_SHSIZE 512
#define IMGPF_NONE 0x00000000
#define IMGPF_INTERPRET 0x00000001
#define IMGPF_RESERVED 0x00000002
#define IMGPF_WAS_64BIT_ADDR 0x00000004
#define IMGPF_IS_64BIT_ADDR 0x00000008
#define IMGPF_SPAWN 0x00000010
#define IMGPF_DISABLE_ASLR 0x00000020
#define IMGPF_ALLOW_DATA_EXEC 0x00000040
#define IMGPF_3P_PLUGINS 0x00000080
#define IMGPF_EXEC 0x00000100
#define IMGPF_HIGH_BITS_ASLR 0x00000200
#define IMGPF_IS_64BIT_DATA 0x00000400
#define IMGPF_DRIVER 0x00000800
#define IMGPF_RESLIDE 0x00001000
#define IMGPF_PLUGIN_HOST_DISABLE_A_KEYS 0x00002000
#define IMGPF_HW_TPRO 0x00004000
#define IMGPF_ROSETTA 0x10000000
#define IMGPF_ALT_ROSETTA 0x20000000
#define IMGPF_RESERVED_2 0x40000000
#define IMGPF_NOJOP 0x80000000
#define IMGPF_SB_DEFAULT 0
#define IMGPF_SB_TRUE 1
#define IMGPF_SB_FALSE 2
#define _POSIX_THREAD_KEYS_MAX 128
#define F_OK 0
#define ACCESSX_MAX_DESCRIPTORS 100
#define _PC_LINK_MAX 1
#define _PC_MAX_CANON 2
#define _PC_MAX_INPUT 3
#define _PC_NAME_MAX 4
#define _PC_PATH_MAX 5
#define _PC_PIPE_BUF 6
#define _PC_CHOWN_RESTRICTED 7
#define _PC_NO_TRUNC 8
#define _PC_VDISABLE 9
#define _PC_NAME_CHARS_MAX 10
#define _PC_CASE_SENSITIVE 11
#define _PC_CASE_PRESERVING 12
#define _PC_EXTENDED_SECURITY_NP 13
#define _PC_AUTH_OPAQUE_NP 14
#define _PC_2_SYMLINKS 15
#define _PC_ALLOC_SIZE_MIN 16
#define _PC_ASYNC_IO 17
#define _PC_FILESIZEBITS 18
#define _PC_PRIO_IO 19
#define _PC_REC_INCR_XFER_SIZE 20
#define _PC_REC_MAX_XFER_SIZE 21
#define _PC_REC_MIN_XFER_SIZE 22
#define _PC_REC_XFER_ALIGN 23
#define _PC_SYMLINK_MAX 24
#define _PC_SYNC_IO 25
#define _PC_XATTR_SIZE_BITS 26
#define _PC_MIN_HOLE_SIZE 27
#define _CS_PATH 1
#define _SYS_CONF_H_ 1
#define D_TAPE 1
#define D_DISK 2
#define D_TTY 3
#define WNOHANG 0x00000001
#define WUNTRACED 0x00000002
#define WCOREFLAG 00200
#define _WSTOPPED 00177
#define WEXITED 0x00000004
#define WSTOPPED 0x00000008
#define WCONTINUED 0x00000010
#define WNOWAIT 0x00000020
#define WAIT_MYPGRP 0
#define PRIO_DARWIN_GPU 5
#define PRIO_DARWIN_GPU_ALLOW 0x1
#define PRIO_DARWIN_GPU_DENY 0x2
#define PRIO_DARWIN_ROLE 6
#define PRIO_DARWIN_ROLE_DEFAULT 0x0
#define PRIO_DARWIN_ROLE_UI_FOCAL 0x1
#define PRIO_DARWIN_ROLE_UI 0x2
#define PRIO_DARWIN_ROLE_NON_UI 0x3
#define PRIO_DARWIN_ROLE_UI_NON_FOCAL 0x4
#define PRIO_DARWIN_ROLE_TAL_LAUNCH 0x5
#define PRIO_DARWIN_ROLE_DARWIN_BG 0x6
#define PRIO_DARWIN_GAME_MODE 7
#define PRIO_DARWIN_CARPLAY_MODE 8
#define PRIO_DARWIN_GAME_MODE_OFF 0x0
#define PRIO_DARWIN_GAME_MODE_ON 0x1
#define PRIO_DARWIN_CARPLAY_MODE_OFF 0x0
#define PRIO_DARWIN_CARPLAY_MODE_ON 0x1
#define IOMON_ENABLE 0x01
#define IOMON_DISABLE 0x02
#define IOPOL_TYPE_VFS_HFS_CASE_SENSITIVITY 1
#define IOPOL_TYPE_VFS_ALTLINK 11
#define IOPOL_TYPE_VFS_NOCACHE_WRITE_FS_BLKSIZE 12
#define IOPOL_VFS_HFS_CASE_SENSITIVITY_DEFAULT 0
#define IOPOL_VFS_HFS_CASE_SENSITIVITY_FORCE_CASE_SENSITIVE 1
#define IOPOL_VFS_ALTLINK_DISABLED 0
#define IOPOL_VFS_ALTLINK_ENABLED 1
#define IOPOL_CMD_GET 0x00000001
#define IOPOL_CMD_SET 0x00000002
#define IPC_CREAT 0001000
#define IPC_EXCL 0002000
#define IPC_NOWAIT 0004000
#define IPC_RMID 0
#define IPC_SET 1
#define IPC_STAT 2
#define IPC_R 0000400
#define IPC_W 0000200
#define IPC_M 0010000
#define O_RDONLY 0x0000
#define O_WRONLY 0x0001
#define O_RDWR 0x0002
#define O_ACCMODE 0x0003
#define FREAD 0x00000001
#define FWRITE 0x00000002
#define O_NONBLOCK 0x00000004
#define O_APPEND 0x00000008
#define O_SHLOCK 0x00000010
#define O_EXLOCK 0x00000020
#define O_ASYNC 0x00000040
#define O_NOFOLLOW 0x00000100
#define O_CREAT 0x00000200
#define O_TRUNC 0x00000400
#define O_EXCL 0x00000800
#define FMARK 0x00001000
#define FDEFER 0x00002000
#define FWASLOCKED 0x00004000
#define O_EVTONLY 0x00008000
#define FWASWRITTEN 0x00010000
#define O_NOCTTY 0x00020000
#define FNOCACHE 0x00040000
#define FNORDAHEAD 0x00080000
#define O_DIRECTORY 0x00100000
#define O_SYMLINK 0x00200000
#define FNODIRECT 0x00800000
#define O_CLOEXEC 0x01000000
#define FENCRYPTED 0x02000000
#define FSINGLE_WRITER 0x04000000
#define O_CLOFORK 0x08000000
#define FUNENCRYPTED 0x10000000
#define O_NOFOLLOW_ANY 0x20000000
#define O_EXEC 0x40000000
#define AT_EACCESS 0x0010
#define AT_SYMLINK_NOFOLLOW 0x0020
#define AT_SYMLINK_FOLLOW 0x0040
#define AT_REMOVEDIR 0x0080
#define AT_REALDEV 0x0200
#define AT_FDONLY 0x0400
#define AT_SYMLINK_NOFOLLOW_ANY 0x0800
#define O_DP_GETRAWENCRYPTED 0x0001
#define O_DP_GETRAWUNENCRYPTED 0x0002
#define O_DP_AUTHENTICATE 0x0004
#define CPF_OVERWRITE 0x0001
#define CPF_IGNORE_MODE 0x0002
#define F_DUPFD 0
#define F_GETFD 1
#define F_SETFD 2
#define F_GETFL 3
#define F_SETFL 4
#define F_GETOWN 5
#define F_SETOWN 6
#define F_GETLK 7
#define F_SETLK 8
#define F_SETLKW 9
#define F_SETLKWTIMEOUT 10
#define F_FLUSH_DATA 40
#define F_CHKCLEAN 41
#define F_PREALLOCATE 42
#define F_SETSIZE 43
#define F_RDADVISE 44
#define F_RDAHEAD 45
#define F_NOCACHE 48
#define F_LOG2PHYS 49
#define F_GETPATH 50
#define F_FULLFSYNC 51
#define F_PATHPKG_CHECK 52
#define F_FREEZE_FS 53
#define F_THAW_FS 54
#define F_GLOBAL_NOCACHE 55
#define F_ADDSIGS 59
#define F_ADDFILESIGS 61
#define F_NODIRECT 62
#define F_GETPROTECTIONCLASS 63
#define F_SETPROTECTIONCLASS 64
#define F_LOG2PHYS_EXT 65
#define F_GETLKPID 66
#define F_SETBACKINGSTORE 70
#define F_GETPATH_MTMINFO 71
#define F_GETCODEDIR 72
#define F_SETNOSIGPIPE 73
#define F_GETNOSIGPIPE 74
#define F_TRANSCODEKEY 75
#define F_SINGLE_WRITER 76
#define F_GETPROTECTIONLEVEL 77
#define F_FINDSIGS 78
#define F_ADDFILESIGS_FOR_DYLD_SIM 83
#define F_BARRIERFSYNC 85
#define F_OFD_SETLK 90
#define F_OFD_SETLKW 91
#define F_OFD_GETLK 92
#define F_OFD_SETLKWTIMEOUT 93
#define F_ADDFILESIGS_RETURN 97
#define F_CHECK_LV 98
#define F_PUNCHHOLE 99
#define F_TRIM_ACTIVE_FILE 100
#define F_SPECULATIVE_READ 101
#define F_GETPATH_NOFIRMLINK 102
#define F_ADDFILESIGS_INFO 103
#define F_ADDFILESUPPL 104
#define F_GETSIGSINFO 105
#define F_SETLEASE 106
#define F_GETLEASE 107
#define F_TRANSFEREXTENTS 110
#define F_ATTRIBUTION_TAG 111
#define F_ADDSIGS_MAIN_BINARY 113
#define FCNTL_FS_SPECIFIC_BASE 0x00010000
#define F_DUPFD_CLOEXEC 67
#define FD_CLOEXEC 1
#define F_RDLCK 1
#define F_UNLCK 2
#define F_WRLCK 3
#define F_WAIT 0x010
#define F_FLOCK 0x020
#define F_POSIX 0x040
#define F_PROV 0x080
#define F_WAKE1_SAFE 0x100
#define F_ABORT 0x200
#define F_OFD_LOCK 0x400
#define F_TRANSFER 0x800
#define F_CONFINED 0x1000
#define F_ALLOCATECONTIG 0x00000002
#define F_ALLOCATEALL 0x00000004
#define F_ALLOCATEPERSIST 0x00000008
#define F_PEOFPOSMODE 3
#define F_VOLPOSMODE 4
#define USER_FSIGNATURES_CDHASH_LEN 20
#define GETSIGSINFO_PLATFORM_BINARY 1
#define LOCK_SH 0x01
#define LOCK_EX 0x02
#define LOCK_NB 0x04
#define LOCK_UN 0x08
#define ATTRIBUTION_NAME_MAX 255
#define F_CREATE_TAG 0x00000001
#define F_DELETE_TAG 0x00000002
#define F_QUERY_TAG 0x00000004
#define O_POPUP 0x80000000
#define O_ALERT 0x20000000
#define S_BLKSIZE 512
#define UF_SETTABLE 0x0000ffff
#define UF_NODUMP 0x00000001
#define UF_IMMUTABLE 0x00000002
#define UF_APPEND 0x00000004
#define UF_OPAQUE 0x00000008
#define UF_COMPRESSED 0x00000020
#define UF_TRACKED 0x00000040
#define UF_DATAVAULT 0x00000080
#define UF_HIDDEN 0x00008000
#define SF_SUPPORTED 0x009f0000
#define SF_SETTABLE 0x3fff0000
#define SF_SYNTHETIC 0xc0000000
#define SF_ARCHIVED 0x00010000
#define SF_IMMUTABLE 0x00020000
#define SF_APPEND 0x00040000
#define SF_RESTRICTED 0x00080000
#define SF_NOUNLINK 0x00100000
#define SF_FIRMLINK 0x00800000
#define SF_DATALESS 0x40000000
#define EF_MAY_SHARE_BLOCKS 0x00000001
#define EF_NO_XATTRS 0x00000002
#define EF_IS_SYNC_ROOT 0x00000004
#define EF_IS_PURGEABLE 0x00000008
#define EF_IS_SPARSE 0x00000010
#define EF_IS_SYNTHETIC 0x00000020
#define EF_SHARES_ALL_BLOCKS 0x00000040
#define MBUF_COPYALL 1000000000
#define __DARWIN_NSIG 32
#define SIGHUP 1
#define SIGINT 2
#define SIGQUIT 3
#define SIGILL 4
#define SIGTRAP 5
#define SIGABRT 6
#define SIGPOLL 7
#define SIGEMT 7
#define SIGFPE 8
#define SIGKILL 9
#define SIGBUS 10
#define SIGSEGV 11
#define SIGSYS 12
#define SIGPIPE 13
#define SIGALRM 14
#define SIGTERM 15
#define SIGURG 16
#define SIGSTOP 17
#define SIGTSTP 18
#define SIGCONT 19
#define SIGCHLD 20
#define SIGTTIN 21
#define SIGTTOU 22
#define SIGIO 23
#define SIGXCPU 24
#define SIGXFSZ 25
#define SIGVTALRM 26
#define SIGPROF 27
#define SIGWINCH 28
#define SIGINFO 29
#define SIGUSR1 30
#define SIGUSR2 31
#define SIGEV_NONE 0
#define SIGEV_SIGNAL 1
#define SIGEV_THREAD 3
#define ILL_NOOP 0
#define ILL_ILLOPC 1
#define ILL_ILLTRP 2
#define ILL_PRVOPC 3
#define ILL_ILLOPN 4
#define ILL_ILLADR 5
#define ILL_PRVREG 6
#define ILL_COPROC 7
#define ILL_BADSTK 8
#define FPE_NOOP 0
#define FPE_FLTDIV 1
#define FPE_FLTOVF 2
#define FPE_FLTUND 3
#define FPE_FLTRES 4
#define FPE_FLTINV 5
#define FPE_FLTSUB 6
#define FPE_INTDIV 7
#define FPE_INTOVF 8
#define SEGV_NOOP 0
#define SEGV_MAPERR 1
#define SEGV_ACCERR 2
#define BUS_NOOP 0
#define BUS_ADRALN 1
#define BUS_ADRERR 2
#define BUS_OBJERR 3
#define TRAP_BRKPT 1
#define TRAP_TRACE 2
#define CLD_NOOP 0
#define CLD_EXITED 1
#define CLD_KILLED 2
#define CLD_DUMPED 3
#define CLD_TRAPPED 4
#define CLD_STOPPED 5
#define CLD_CONTINUED 6
#define POLL_IN 1
#define POLL_OUT 2
#define POLL_MSG 3
#define POLL_ERR 4
#define POLL_PRI 5
#define POLL_HUP 6
#define SA_ONSTACK 0x0001
#define SA_RESTART 0x0002
#define SA_RESETHAND 0x0004
#define SA_NOCLDSTOP 0x0008
#define SA_NODEFER 0x0010
#define SA_NOCLDWAIT 0x0020
#define SA_SIGINFO 0x0040
#define SA_USERTRAMP 0x0100
#define SA_64REGSET 0x0200
#define SIG_BLOCK 1
#define SIG_UNBLOCK 2
#define SIG_SETMASK 3
#define SI_USER 0x10001
#define SI_QUEUE 0x10002
#define SI_TIMER 0x10003
#define SI_ASYNCIO 0x10004
#define SI_MESGQ 0x10005
#define SS_ONSTACK 0x0001
#define SS_DISABLE 0x0004
#define MINSIGSTKSZ 32768
#define SIGSTKSZ 131072
#define __DARWIN_MAXNAMLEN 255
#define __DARWIN_MAXPATHLEN 1024
#define DT_UNKNOWN 0
#define DT_FIFO 1
#define DT_CHR 2
#define DT_DIR 4
#define DT_BLK 6
#define DT_REG 8
#define DT_LNK 10
#define DT_SOCK 12
#define DT_WHT 14
#define POSIX_SPAWN_RESETIDS 0x0001
#define POSIX_SPAWN_SETPGROUP 0x0002
#define POSIX_SPAWN_SETSIGDEF 0x0004
#define POSIX_SPAWN_SETSIGMASK 0x0008
#define POSIX_SPAWN_SETSCHEDPARAM 0x0010
#define POSIX_SPAWN_SETSCHEDULER 0x0020
#define POSIX_SPAWN_SETEXEC 0x0040
#define POSIX_SPAWN_START_SUSPENDED 0x0080
#define POSIX_SPAWN_SETSID 0x0400
#define POSIX_SPAWN_CLOEXEC_DEFAULT 0x4000
#define _POSIX_SPAWN_RESLIDE 0x0800
#define POSIX_SPAWN_PCONTROL_NONE 0x0000
#define POSIX_SPAWN_PCONTROL_THROTTLE 0x0001
#define POSIX_SPAWN_PCONTROL_SUSPEND 0x0002
#define POSIX_SPAWN_PCONTROL_KILL 0x0003
#define POSIX_SPAWN_PANIC_ON_CRASH 0x1
#define POSIX_SPAWN_PANIC_ON_NON_ZERO_EXIT 0x2
#define POSIX_SPAWN_PANIC_ON_EXIT 0x4
#define POSIX_SPAWN_PANIC_ON_SPAWN_FAIL 0x8
#define PROT_NONE 0x00
#define PROT_READ 0x01
#define PROT_WRITE 0x02
#define PROT_EXEC 0x04
#define MAP_SHARED 0x0001
#define MAP_PRIVATE 0x0002
#define MAP_FIXED 0x0010
#define MAP_RENAME 0x0020
#define MAP_NORESERVE 0x0040
#define MAP_RESERVED0080 0x0080
#define MAP_NOEXTEND 0x0100
#define MAP_HASSEMAPHORE 0x0200
#define MAP_NOCACHE 0x0400
#define MAP_JIT 0x0800
#define MAP_FILE 0x0000
#define MAP_ANON 0x1000
#define MAP_RESILIENT_CODESIGN 0x2000
#define MAP_RESILIENT_MEDIA 0x4000
#define MAP_32BIT 0x8000
#define MAP_TRANSLATED_ALLOW_EXECUTE 0x20000
#define MAP_UNIX03 0x40000
#define MAP_TPRO 0x80000
#define MCL_CURRENT 0x0001
#define MCL_FUTURE 0x0002
#define MS_ASYNC 0x0001
#define MS_INVALIDATE 0x0002
#define MS_SYNC 0x0010
#define MS_KILLPAGES 0x0004
#define MS_DEACTIVATE 0x0008
#define POSIX_MADV_NORMAL 0
#define POSIX_MADV_RANDOM 1
#define POSIX_MADV_SEQUENTIAL 2
#define POSIX_MADV_WILLNEED 3
#define POSIX_MADV_DONTNEED 4
#define MADV_FREE 5
#define MADV_ZERO_WIRED_PAGES 6
#define MADV_FREE_REUSABLE 7
#define MADV_FREE_REUSE 8
#define MADV_CAN_REUSE 9
#define MADV_PAGEOUT 10
#define MADV_ZERO 11
#define MINCORE_INCORE 0x1
#define MINCORE_REFERENCED 0x2
#define MINCORE_MODIFIED 0x4
#define MINCORE_REFERENCED_OTHER 0x8
#define MINCORE_MODIFIED_OTHER 0x10
#define MINCORE_PAGED_OUT 0x20
#define MINCORE_COPIED 0x40
#define MINCORE_ANONYMOUS 0x80
#define B_WRITE 0x00000000
#define B_READ 0x00000001
#define B_ASYNC 0x00000002
#define B_NOCACHE 0x00000004
#define B_DELWRI 0x00000008
#define B_LOCKED 0x00000010
#define B_PHYS 0x00000020
#define B_CLUSTER 0x00000040
#define B_PAGEIO 0x00000080
#define B_META 0x00000100
#define B_RAW 0x00000200
#define B_FUA 0x00000400
#define B_PASSIVE 0x00000800
#define B_IOSTREAMING 0x00001000
#define B_THROTTLED_IO 0x00002000
#define B_ENCRYPTED_IO 0x00004000
#define B_STATICCONTENT 0x00008000
#define BUF_WAIT 0x01
#define BUF_WRITE_DATA 0x0001
#define BUF_SKIP_META 0x0002
#define BUF_INVALIDATE_LOCKED 0x0004
#define BUF_SKIP_NONLOCKED 0x01
#define BUF_SKIP_LOCKED 0x02
#define BUF_SCAN_CLEAN 0x04
#define BUF_SCAN_DIRTY 0x08
#define BUF_NOTIFY_BUSY 0x10
#define BUF_RETURNED 0
#define BUF_RETURNED_DONE 1
#define BUF_CLAIMED 2
#define BUF_CLAIMED_DONE 3
#define BLK_READ 0x01
#define BLK_WRITE 0x02
#define BLK_META 0x10
#define BLK_ONLYVALID 0x80000000
#define LOG_EMERG 0
#define LOG_ALERT 1
#define LOG_CRIT 2
#define LOG_ERR 3
#define LOG_WARNING 4
#define LOG_NOTICE 5
#define LOG_INFO 6
#define LOG_DEBUG 7
#define LOG_PRIMASK 0x07
#define INTERNAL_NOPRI 0x10
#define LOG_NFACILITIES 25
#define LOG_FACMASK 0x03f8
#define LOG_PID 0x01
#define LOG_CONS 0x02
#define LOG_ODELAY 0x04
#define LOG_NDELAY 0x08
#define LOG_NOWAIT 0x10
#define LOG_PERROR 0x20
#define CRF_NOMEMBERD 0x00000001
#define CRF_MAC_ENFORCE 0x00000002
#define XUCRED_VERSION 0
#define DK_FEATURE_BARRIER 0x00000002
#define DK_FEATURE_PRIORITY 0x00000004
#define DK_FEATURE_UNMAP 0x00000010
#define DK_SYNCHRONIZE_OPTION_BARRIER 0x00000002
#define DK_CORESTORAGE_PIN_YOUR_METADATA 0x00000001
#define DK_CORESTORAGE_ENABLE_HOTFILES 0x00000002
#define DK_CORESTORAGE_PIN_YOUR_SWAPFILE 0x00000004
#define DK_PROVISION_TYPE_MAPPED 0x00
#define DK_PROVISION_TYPE_DEALLOCATED 0x01
#define DK_PROVISION_TYPE_ANCHORED 0x02
#define DK_LOCATION_INTERNAL 0x00000000
#define DK_LOCATION_EXTERNAL 0x00000001
#define DK_FEATURE_FORCE_UNIT_ACCESS 0x00000001
#define DK_ENCRYPTION_TYPE_AES_CBC 1
#define DK_ENCRYPTION_TYPE_AES_XEX 2
#define DK_ENCRYPTION_TYPE_AES_XTS 3
#define DK_TIER_MASK 0xC0
#define DK_TIER_SHIFT 6
#define SOL_LOCAL 0
#define LOCAL_PEERCRED 0x001
#define LOCAL_PEERPID 0x002
#define LOCAL_PEEREPID 0x003
#define LOCAL_PEERUUID 0x004
#define LOCAL_PEEREUUID 0x005
#define LOCAL_PEERTOKEN 0x006
#define _SYS_TIMEX_H_ 1
#define NTP_API 4
#define MINSEC 256
#define MAXSEC 2048
#define MAXTC 10
#define MOD_OFFSET 0x0001
#define MOD_FREQUENCY 0x0002
#define MOD_MAXERROR 0x0004
#define MOD_ESTERROR 0x0008
#define MOD_STATUS 0x0010
#define MOD_TIMECONST 0x0020
#define MOD_PPSMAX 0x0040
#define MOD_TAI 0x0080
#define MOD_MICRO 0x1000
#define MOD_NANO 0x2000
#define MOD_CLKB 0x4000
#define MOD_CLKA 0x8000
#define STA_PLL 0x0001
#define STA_PPSFREQ 0x0002
#define STA_PPSTIME 0x0004
#define STA_FLL 0x0008
#define STA_INS 0x0010
#define STA_DEL 0x0020
#define STA_UNSYNC 0x0040
#define STA_FREQHOLD 0x0080
#define STA_PPSSIGNAL 0x0100
#define STA_PPSJITTER 0x0200
#define STA_PPSWANDER 0x0400
#define STA_PPSERROR 0x0800
#define STA_CLOCKERR 0x1000
#define STA_NANO 0x2000
#define STA_MODE 0x4000
#define STA_CLK 0x8000
#define TIME_OK 0
#define TIME_INS 1
#define TIME_DEL 2
#define TIME_OOP 3
#define TIME_WAIT 4
#define TIME_ERROR 5
#define MT_FREE 0
#define MT_DATA 1
#define MT_HEADER 2
#define MT_SOCKET 3
#define MT_PCB 4
#define MT_RTABLE 5
#define MT_HTABLE 6
#define MT_ATABLE 7
#define MT_SONAME 8
#define MT_SOOPTS 10
#define MT_FTABLE 11
#define MT_RIGHTS 12
#define MT_IFADDR 13
#define MT_CONTROL 14
#define MT_OOBDATA 15
#define MT_TAG 16
#define MT_MAX 32
#define MAX_MBUF_CNAME 15
#define MCS_DISABLED 0
#define MCS_ONLINE 1
#define MCS_PURGING 2
#define MCS_OFFLINE 3
#define MSG_NOERROR 0010000
#define MSGSSZ 8
#define MSGSEG 2048
#define MSGMNB 2048
#define MSGMNI 40
#define MSGTQL 40
#define MSG_LOCKED 001000
#define DBG_MACH 1
#define DBG_NETWORK 2
#define DBG_FSYSTEM 3
#define DBG_BSD 4
#define DBG_IOKIT 5
#define DBG_DRIVERS 6
#define DBG_TRACE 7
#define DBG_DLIL 8
#define DBG_PTHREAD 9
#define DBG_CORESTORAGE 10
#define DBG_CG 11
#define DBG_MONOTONIC 12
#define DBG_MISC 20
#define DBG_SECURITY 30
#define DBG_DYLD 31
#define DBG_QT 32
#define DBG_APPS 33
#define DBG_LAUNCHD 34
#define DBG_SILICON 35
#define DBG_PERF 37
#define DBG_IMPORTANCE 38
#define DBG_BANK 40
#define DBG_XPC 41
#define DBG_ATM 42
#define DBG_ARIADNE 43
#define DBG_DAEMON 44
#define DBG_ENERGYTRACE 45
#define DBG_DISPATCH 46
#define DBG_IMG 49
#define DBG_UMALLOC 51
#define DBG_TURNSTILE 53
#define DBG_AUDIO 54
#define DBG_MIG 255
#define DBG_MACH_EXCP_KTRAP_x86 0x02
#define DBG_MACH_EXCP_DFLT 0x03
#define DBG_MACH_EXCP_SYNC_ARM 0x03
#define DBG_MACH_EXCP_IFLT 0x04
#define DBG_MACH_EXCP_SERR_ARM 0x04
#define DBG_MACH_EXCP_INTR 0x05
#define DBG_MACH_EXCP_ALNG 0x06
#define DBG_MACH_EXCP_UTRAP_x86 0x07
#define DBG_MACH_EXCP_FP 0x08
#define DBG_MACH_EXCP_DECI 0x09
#define DBG_MACH_CHUD 0x0A
#define DBG_MACH_SIGNPOST 0x0A
#define DBG_MACH_EXCP_SC 0x0C
#define DBG_MACH_EXCP_TRACE 0x0D
#define DBG_MACH_EXCP_EMUL 0x0E
#define DBG_MACH_IHDLR 0x10
#define DBG_MACH_IPC 0x20
#define DBG_MACH_RESOURCE 0x25
#define DBG_MACH_EXCLAVES 0x2A
#define DBG_MACH_EXCLAVES_SCHEDULER 0x2B
#define DBG_MACH_EPOCH_SYNC 0x2C
#define DBG_MACH_VM 0x30
#define DBG_MACH_LEAKS 0x31
#define DBG_MACH_WORKINGSET 0x32
#define DBG_MACH_SCHED 0x40
#define DBG_MACH_MSGID_INVALID 0x50
#define DBG_MACH_LOCKS 0x60
#define DBG_MACH_PMAP 0x70
#define DBG_MACH_CLOCK 0x80
#define DBG_MACH_MP 0x90
#define DBG_MACH_VM_PRESSURE 0xA0
#define DBG_MACH_STACKSHOT 0xA1
#define DBG_MACH_SFI 0xA2
#define DBG_MACH_ENERGY_PERF 0xA3
#define DBG_MACH_SYSDIAGNOSE 0xA4
#define DBG_MACH_ZALLOC 0xA5
#define DBG_MACH_THREAD_GROUP 0xA6
#define DBG_MACH_COALITION 0xA7
#define DBG_MACH_SHAREDREGION 0xA8
#define DBG_MACH_SCHED_CLUTCH 0xA9
#define DBG_MACH_IO 0xAA
#define DBG_MACH_WORKGROUP 0xAB
#define DBG_MACH_HV 0xAC
#define DBG_MACH_KCOV 0xAD
#define DBG_MACH_MACHDEP_EXCP_SC_x86 0xAE
#define DBG_MACH_MACHDEP_EXCP_SC_ARM 0xAF
#define DBG_MACH_VM_RECLAIM 0xB0
#define DBC_MACH_IO_MMIO_READ 0x1
#define DBC_MACH_IO_MMIO_WRITE 0x2
#define DBC_MACH_IO_PHYS_READ 0x3
#define DBC_MACH_IO_PHYS_WRITE 0x4
#define DBC_MACH_IO_PORTIO_READ 0x5
#define DBC_MACH_IO_PORTIO_WRITE 0x6
#define DBG_INTR_TYPE_UNKNOWN 0x0
#define DBG_INTR_TYPE_IPI 0x1
#define DBG_INTR_TYPE_TIMER 0x2
#define DBG_INTR_TYPE_OTHER 0x3
#define DBG_INTR_TYPE_PMI 0x4
#define DBG_INTR_TYPE_RSVD1 0x5
#define MACH_SCHED 0x0
#define MACH_STACK_ATTACH 0x1
#define MACH_STACK_HANDOFF 0x2
#define MACH_CALL_CONT 0x3
#define MACH_CALLOUT 0x4
#define MACH_STACK_DETACH 0x5
#define MACH_MAKE_RUNNABLE 0x6
#define MACH_PROMOTE 0x7
#define MACH_DEMOTE 0x8
#define MACH_IDLE 0x9
#define MACH_STACK_DEPTH 0xa
#define MACH_MOVED 0xb
#define MACH_PSET_LOAD_AVERAGE 0xc
#define MACH_AMP_DEBUG 0xd
#define MACH_FAILSAFE 0xe
#define MACH_BLOCK 0xf
#define MACH_WAIT 0x10
#define MACH_GET_URGENCY 0x14
#define MACH_URGENCY 0x15
#define MACH_REDISPATCH 0x16
#define MACH_REMOTE_AST 0x17
#define MACH_SCHED_CHOOSE_PROCESSOR 0x18
#define MACH_DEEP_IDLE 0x19
#define MACH_CPU_THROTTLE_DISABLE 0x1b
#define MACH_RW_PROMOTE 0x1c
#define MACH_RW_DEMOTE 0x1d
#define MACH_SCHED_MAINTENANCE 0x1f
#define MACH_DISPATCH 0x20
#define MACH_QUANTUM_HANDOFF 0x21
#define MACH_SCHED_THREAD_SWITCH 0x23
#define MACH_SCHED_SMT_BALANCE 0x24
#define MACH_REMOTE_DEFERRED_AST 0x25
#define MACH_REMOTE_CANCEL_AST 0x26
#define MACH_SCHED_CHANGE_PRIORITY 0x27
#define MACH_SCHED_UPDATE_REC_CORES 0x28
#define MACH_STACK_WAIT 0x29
#define MACH_THREAD_BIND 0x2a
#define MACH_WAITQ_PROMOTE 0x2b
#define MACH_WAITQ_DEMOTE 0x2c
#define MACH_SCHED_LOAD 0x2d
#define MACH_REC_CORES_FAILSAFE 0x2e
#define MACH_SCHED_QUANTUM_EXPIRED 0x2f
#define MACH_EXEC_PROMOTE 0x30
#define MACH_EXEC_DEMOTE 0x31
#define MACH_AMP_SIGNAL_SPILL 0x32
#define MACH_AMP_STEAL 0x33
#define MACH_SCHED_LOAD_EFFECTIVE 0x34
#define MACH_QUIESCENT_COUNTER 0x38
#define MACH_TURNSTILE_USER_CHANGE 0x39
#define MACH_AMP_RECOMMENDATION_CHANGE 0x3a
#define MACH_AMP_PERFCTL_POLICY_CHANGE 0x3b
#define MACH_TURNSTILE_KERNEL_CHANGE 0x40
#define MACH_SCHED_WI_AUTO_JOIN 0x41
#define MACH_SCHED_WI_DEFERRED_FINISH 0x42
#define MACH_SET_RT_DEADLINE 0x43
#define MACH_CANCEL_RT_DEADLINE 0x44
#define MACH_RT_SIGNAL_SPILL 0x45
#define MACH_RT_STEAL 0x46
#define MACH_PENDING_AST_URGENT 0x47
#define MACH_SCHED_THREAD_SELECT 0x48
#define MACH_SCHED_NEXT_PROCESSOR 0x49
#define MACH_PSET_AVG_EXEC_TIME 0x50
#define MACH_SUSPEND_USERSPACE 0x51
#define MACH_PREEMPTION_EXPIRED 0x52
#define MACH_FLOOR_PROMOTE 0x53
#define MACH_FLOOR_DEMOTE 0x54
#define MACH_INT_MASKED_EXPIRED 0x55
#define MACH_INT_HANDLED_EXPIRED 0x56
#define MACH_UPDATE_POWERED_CORES 0x58
#define MACH_MODE_DEMOTE_THROTTLED 0x59
#define MACH_MODE_DEMOTE_FAILSAFE 0x5a
#define MACH_MODE_DEMOTE_RT_DISALLOWED 0x5b
#define MACH_MODE_UNDEMOTE_THROTTLED 0x5c
#define MACH_MODE_UNDEMOTE_FAILSAFE 0x5d
#define MACH_MODE_UNDEMOTE_RT_DISALLOWED 0x5e
#define MACH_INT_MASKED_RESET 0x5f
#define MACH_RT_DISALLOWED_WORK_INTERVAL 0x60
#define MACH_SCHED_WI_EXTERNAL_WAKEUP 0x61
#define MACH_SCHED_AST_CHECK 0x62
#define MACH_SCHED_PREEMPT_TIMER_ACTIVE 0x63
#define MACH_PROCESSOR_SHUTDOWN 0x64
#define MACH_SCHED_CLUTCH_ROOT_BUCKET_STATE 0x0
#define MACH_SCHED_CLUTCH_TG_BUCKET_STATE 0x1
#define MACH_SCHED_CLUTCH_THREAD_SELECT 0x2
#define MACH_SCHED_CLUTCH_THREAD_STATE 0x3
#define MACH_SCHED_CLUTCH_TG_BUCKET_PRI 0x4
#define MACH_SCHED_EDGE_CLUSTER_OVERLOAD 0x5
#define MACH_SCHED_EDGE_STEAL 0x6
#define MACH_SCHED_EDGE_REBAL_RUNNABLE 0x7
#define MACH_SCHED_EDGE_REBAL_RUNNING 0x8
#define MACH_SCHED_EDGE_SHOULD_YIELD 0x9
#define MACH_SCHED_CLUTCH_THR_COUNT 0xa
#define MACH_SCHED_EDGE_LOAD_AVG 0xb
#define MACH_SCHED_EDGE_CLUSTER_SHARED_LOAD 0xc
#define MACH_SCHED_EDGE_RSRC_HEAVY_THREAD 0xd
#define MACH_SCHED_EDGE_SHARED_RSRC_MIGRATE 0xe
#define WORKGROUP_INTERVAL_CREATE 0x0
#define WORKGROUP_INTERVAL_DESTROY 0x1
#define WORKGROUP_INTERVAL_CHANGE 0x2
#define WORKGROUP_INTERVAL_START 0x3
#define WORKGROUP_INTERVAL_UPDATE 0x4
#define WORKGROUP_INTERVAL_FINISH 0x5
#define WORKGROUP_INTERVAL_SET_WORKLOAD_ID 0x6
#define WORKGROUP_INTERVAL_SET_WORKLOAD_ID_NAME 0x7
#define KCOV_STKSZ_THRESHOLD_ABOVE 0x0
#define KCOV_STKSZ_THRESHOLD_BELOW 0x1
#define DBG_VM_VNODE_PAGEOUT 0x001
#define DBG_VM_FAULT_INTERNAL 0x002
#define DBG_VM_PURGEABLE_TOKEN_ADD 0x040
#define DBG_VM_PURGEABLE_TOKEN_DELETE 0x041
#define DBG_VM_PURGEABLE_TOKEN_RIPEN 0x042
#define DBG_VM_PURGEABLE_OBJECT_ADD 0x048
#define DBG_VM_PURGEABLE_OBJECT_REMOVE 0x049
#define DBG_VM_PURGEABLE_OBJECT_PURGE 0x04a
#define DBG_VM_PURGEABLE_OBJECT_PURGE_ALL 0x04b
#define DBG_VM_PURGEABLE_OBJECT_PURGE_ONE 0x04c
#define DBG_VM_PURGEABLE_OBJECT_PURGE_LOOP 0x04e
#define DBG_VM_MAP_PARTIAL_REAP 0x054
#define DBG_VM_MAP_WILLNEED 0x055
#define DBG_VM_FAULT_CHECK_ZFDELAY 0x100
#define DBG_VM_FAULT_COWDELAY 0x101
#define DBG_VM_FAULT_ZFDELAY 0x102
#define DBG_VM_FAULT_COMPRESSORDELAY 0x103
#define DBG_VM_PAGEOUT_SCAN 0x104
#define DBG_VM_PAGEOUT_BALANCE 0x105
#define DBG_VM_PAGEOUT_FREELIST 0x106
#define DBG_VM_PAGEOUT_PURGEONE 0x107
#define DBG_VM_PAGEOUT_CACHE_EVICT 0x108
#define DBG_VM_PAGEOUT_THREAD_BLOCK 0x109
#define DBG_VM_PAGEOUT_JETSAM 0x10A
#define DBG_VM_INFO1 0x10B
#define DBG_VM_INFO2 0x10C
#define DBG_VM_INFO3 0x10D
#define DBG_VM_INFO4 0x10E
#define DBG_VM_INFO5 0x10F
#define DBG_VM_INFO6 0x110
#define DBG_VM_INFO7 0x111
#define DBG_VM_INFO8 0x112
#define DBG_VM_INFO9 0x113
#define DBG_VM_INFO10 0x114
#define DBG_VM_UPL_PAGE_WAIT 0x120
#define DBG_VM_IOPL_PAGE_WAIT 0x121
#define DBG_VM_PAGE_WAIT_BLOCK 0x122
#define DBG_VM_PAGE_SLEEP 0x123
#define DBG_VM_PAGE_EXPEDITE 0x124
#define DBG_VM_PAGE_EXPEDITE_NO_MEMORY 0x125
#define DBG_VM_PAGE_GRAB 0x126
#define DBG_VM_PAGE_RELEASE 0x127
#define DBG_VM_COMPRESSOR_COMPACT_AND_SWAP 0x128
#define DBG_VM_COMPRESSOR_DELAYED_COMPACT 0x129
#define DBG_VM_OBJECT_SLEEP 0x12a
#define DBG_VM_PAGE_WAKEUP 0x12b
#define DBG_VM_PAGE_WAKEUP_DONE 0x12c
#define DBG_VM_PRESSURE_EVENT 0x130
#define DBG_VM_EXECVE 0x131
#define DBG_VM_WAKEUP_COMPACTOR_SWAPPER 0x132
#define DBG_VM_UPL_REQUEST 0x133
#define DBG_VM_IOPL_REQUEST 0x134
#define DBG_VM_KERN_REQUEST 0x135
#define DBG_VM_DATA_WRITE 0x140
#define DBG_VM_PRESSURE_LEVEL_CHANGE 0x141
#define DBG_VM_PHYS_WRITE_ACCT 0x142
#define DBG_VM_MAP_LOOKUP_ENTRY_FAILURE 0x143
#define VM_DISCONNECT_ALL_PAGE_MAPPINGS 0x00
#define VM_DISCONNECT_TASK_PAGE_MAPPINGS 0x01
#define VM_REAL_FAULT_ADDR_INTERNAL 0x02
#define VM_REAL_FAULT_ADDR_PURGABLE 0x03
#define VM_REAL_FAULT_ADDR_EXTERNAL 0x04
#define VM_REAL_FAULT_ADDR_SHAREDCACHE 0x05
#define VM_REAL_FAULT_FAST 0x06
#define VM_REAL_FAULT_SLOW 0x07
#define VM_MAP_LOOKUP_OBJECT 0x08
#define DBG_ZERO_FILL_FAULT 0x01
#define DBG_PAGEIN_FAULT 0x02
#define DBG_COW_FAULT 0x03
#define DBG_CACHE_HIT_FAULT 0x04
#define DBG_NZF_PAGE_FAULT 0x05
#define DBG_GUARD_FAULT 0x06
#define DBG_PAGEINV_FAULT 0x07
#define DBG_PAGEIND_FAULT 0x08
#define DBG_COMPRESSOR_FAULT 0x09
#define DBG_COMPRESSOR_SWAPIN_FAULT 0x0a
#define DBG_COR_FAULT 0x0b
#define MACH_TASK_SUSPEND 0x0
#define MACH_TASK_RESUME 0x1
#define MACH_THREAD_SET_VOUCHER 0x2
#define MACH_IPC_MSG_SEND 0x3
#define MACH_IPC_MSG_RECV 0x4
#define MACH_IPC_MSG_RECV_VOUCHER_REFUSED 0x5
#define MACH_IPC_KMSG_FREE 0x6
#define MACH_IPC_VOUCHER_CREATE 0x7
#define MACH_IPC_VOUCHER_CREATE_ATTR_DATA 0x8
#define MACH_IPC_VOUCHER_DESTROY 0x9
#define MACH_IPC_KMSG_INFO 0xa
#define MACH_IPC_KMSG_LINK 0xb
#define MACH_IPC_PORT_ENTRY_MODIFY 0xc
#define MACH_IPC_DESTROY_GUARDED_DESC 0xd
#define MACH_THREAD_SUSPEND 0xe
#define MACH_THREAD_RESUME 0xf
#define MACH_EXCLAVES_SWITCH 0x0
#define MACH_EXCLAVES_XNUPROXY 0x1
#define MACH_EXCLAVES_RPC 0x2
#define MACH_EXCLAVES_UPCALL 0x3
#define MACH_EXCLAVES_BOOT_TASK 0x4
#define MACH_EXCLAVES_SCHEDULER_YIELD 0x0
#define MACH_EXCLAVES_SCHEDULER_SPAWNED 0x1
#define MACH_EXCLAVES_SCHEDULER_TERMINATED 0x2
#define MACH_EXCLAVES_SCHEDULER_WAIT 0x3
#define MACH_EXCLAVES_SCHEDULER_WAKE 0x4
#define MACH_EXCLAVES_SCHEDULER_SUSPENDED 0x5
#define MACH_EXCLAVES_SCHEDULER_RESUMED 0x6
#define MACH_EXCLAVES_SCHEDULER_INTERRUPTED 0x7
#define MACH_EXCLAVES_SCHEDULER_NOTHING_SCHEDULED 0x8
#define MACH_EXCLAVES_SCHEDULER_ALL_EXCLAVES_BOOTED 0x9
#define MACH_EXCLAVES_SCHEDULER_EARLY_ALLOC 0xa
#define MACH_EPOCH_SYNC_WAIT_STALE 0x0
#define MACH_EPOCH_SYNC_WAIT 0x1
#define MACH_EPOCH_SYNC_WAKE_NO_WAITERS 0x2
#define MACH_EPOCH_SYNC_WAKE_ONE 0x3
#define MACH_EPOCH_SYNC_WAKE_ALL 0x4
#define MACH_EPOCH_SYNC_WAKE_ONE_WITH_OWNER 0x5
#define MACH_EPOCH_SYNC_WAKE_THREAD 0x6
#define MACH_THREAD_GROUP_NEW 0x0
#define MACH_THREAD_GROUP_FREE 0x1
#define MACH_THREAD_GROUP_SET 0x2
#define MACH_THREAD_GROUP_NAME 0x3
#define MACH_THREAD_GROUP_NAME_FREE 0x4
#define MACH_THREAD_GROUP_FLAGS 0x5
#define MACH_THREAD_GROUP_BLOCK 0x6
#define MACH_THREAD_GROUP_PREADOPT 0x7
#define MACH_THREAD_GROUP_PREADOPT_NEXTTIME 0x8
#define MACH_THREAD_GROUP_PREADOPT_CLEAR 0x9
#define MACH_THREAD_GROUP_PREADOPT_NA 0xa
#define MACH_COALITION_NEW 0x0
#define MACH_COALITION_FREE 0x1
#define MACH_COALITION_ADOPT 0x2
#define MACH_COALITION_REMOVE 0x3
#define MACH_COALITION_THREAD_GROUP_SET 0x4
#define PMAP__CREATE 0x0
#define PMAP__DESTROY 0x1
#define PMAP__PROTECT 0x2
#define PMAP__PAGE_PROTECT 0x3
#define PMAP__ENTER 0x4
#define PMAP__REMOVE 0x5
#define PMAP__NEST 0x6
#define PMAP__UNNEST 0x7
#define PMAP__FLUSH_TLBS 0x8
#define PMAP__UPDATE_INTERRUPT 0x9
#define PMAP__ATTRIBUTE_CLEAR 0xa
#define PMAP__REUSABLE 0xb
#define PMAP__QUERY_RESIDENT 0xc
#define PMAP__FLUSH_KERN_TLBS 0xd
#define PMAP__FLUSH_DELAYED_TLBS 0xe
#define PMAP__FLUSH_TLBS_TO 0xf
#define PMAP__FLUSH_EPT 0x10
#define PMAP__FAST_FAULT 0x11
#define PMAP__SWITCH 0x12
#define PMAP__TTE 0x13
#define PMAP__SWITCH_USER_TTB 0x14
#define PMAP__UPDATE_CACHING 0x15
#define PMAP__ATTRIBUTE_CLEAR_RANGE 0x16
#define PMAP__CLEAR_USER_TTB 0x17
#define PMAP__IOMMU_INIT 0x18
#define PMAP__IOMMU_IOVMALLOC 0x19
#define PMAP__IOMMU_IOVMFREE 0x1a
#define PMAP__IOMMU_MAP 0x1b
#define PMAP__IOMMU_UNMAP 0x1c
#define PMAP__IOMMU_IOCTL 0x1d
#define PMAP__IOMMU_GRANT_PAGE 0x1e
#define PMAP__BATCH_UPDATE_CACHING 0x1f
#define PMAP__COLLECT_CACHE_OPS 0x20
#define MACH_EPOCH_CHANGE 0x0
#define MACH_BRIDGE_RCV_TS 0x1
#define MACH_BRIDGE_REMOTE_TIME 0x2
#define MACH_BRIDGE_RESET_TS 0x3
#define MACH_BRIDGE_TS_PARAMS 0x4
#define MACH_BRIDGE_SKIP_TS 0x5
#define MACH_BRIDGE_TS_MISMATCH 0x6
#define MACH_BRIDGE_OBSV_RATE 0x7
#define MICROSTACKSHOT_RECORD 0x0
#define MICROSTACKSHOT_GATHER 0x1
#define STACKSHOT_RECORD 0x2
#define STACKSHOT_RECORD_SHORT 0x3
#define STACKSHOT_KERN_RECORD 0x4
#define SYSDIAGNOSE_NOTIFY_USER 0x0
#define SYSDIAGNOSE_FULL 0x1
#define SYSDIAGNOSE_STACKSHOT 0x2
#define SYSDIAGNOSE_TAILSPIN 0x3
#define SFI_SET_WINDOW 0x0
#define SFI_CANCEL_WINDOW 0x1
#define SFI_SET_CLASS_OFFTIME 0x2
#define SFI_CANCEL_CLASS_OFFTIME 0x3
#define SFI_THREAD_DEFER 0x4
#define SFI_OFF_TIMER 0x5
#define SFI_ON_TIMER 0x6
#define SFI_WAIT_CANCELED 0x7
#define SFI_PID_SET_MANAGED 0x8
#define SFI_PID_CLEAR_MANAGED 0x9
#define SFI_GLOBAL_DEFER 0xa
#define ZALLOC_ZCRAM 0x0
#define RMON_ENABLE_CPUUSAGE_MONITOR 0x001
#define RMON_CPUUSAGE_VIOLATED 0x002
#define RMON_CPUUSAGE_SUSPENDED 0x003
#define RMON_CPUUSAGE_VIOLATED_K32A 0x004
#define RMON_CPUUSAGE_VIOLATED_K32B 0x005
#define RMON_CPUUSAGE_RESUMED 0x006
#define RMON_DISABLE_CPUUSAGE_MONITOR 0x00f
#define RMON_ENABLE_CPUWAKES_MONITOR 0x011
#define RMON_CPUWAKES_VIOLATED 0x012
#define RMON_CPUWAKES_VIOLATED_K32A 0x014
#define RMON_CPUWAKES_VIOLATED_K32B 0x015
#define RMON_DISABLE_CPUWAKES_MONITOR 0x01f
#define RMON_ENABLE_IO_MONITOR 0x021
#define RMON_LOGWRITES_VIOLATED 0x022
#define RMON_PHYSWRITES_VIOLATED 0x023
#define RMON_LOGWRITES_VIOLATED_K32A 0x024
#define RMON_LOGWRITES_VIOLATED_K32B 0x025
#define RMON_DISABLE_IO_MONITOR 0x02f
#define HV_X86_ENTER 0x00
#define HV_X86_ENTER_ERROR 0x01
#define HV_X86_TRAP_TASK 0x02
#define HV_X86_TRAP_THREAD 0x03
#define HV_X86_INTERRUPT_INJECT 0x04
#define HV_X86_INTERRUPT_RECV 0x05
#define HV_X86_INTERRUPT_SEND 0x06
#define HV_X86_IPI_SEND 0x07
#define HV_X86_NMI_INJECT 0x08
#define HV_X86_NMI_SEND 0x09
#define HV_X86_LSC_HIT 0x0a
#define HV_X86_LSC_INSERT 0x0b
#define HV_X86_LSC_INSERT_IMM32 0x0c
#define HV_X86_LSC_INVALID 0x0d
#define HV_X86_LSC_INVALIDATE 0x0e
#define HV_X86_LSC_MISS 0x0f
#define HV_X86_TIMER_CANCEL 0x10
#define HV_X86_TIMER_FIRE 0x11
#define HV_X86_TIMER_SCHEDULE 0x12
#define HV_X86_APIC_ACCESS_EXIT 0x13
#define HV_X86_APIC_WRITE_EXIT 0x14
#define HV_X86_EPT_VIOLATION_EXIT 0x15
#define HV_X86_EXC_NMI_EXIT 0x16
#define HV_X86_HLT_EXIT 0x17
#define HV_X86_IO_EXIT 0x18
#define HV_X86_IRQ_EXIT 0x19
#define HV_X86_IRQ_WND_EXIT 0x1a
#define HV_X86_MOV_DR_EXIT 0x1b
#define HV_X86_NMI_WND_EXIT 0x1c
#define HV_X86_RDMSR_EXIT 0x1d
#define HV_X86_RDPMC_EXIT 0x1e
#define HV_X86_TPR_THRESHOLD_EXIT 0x1f
#define HV_X86_VMX_TIMER_EXPIRED_EXIT 0x20
#define HV_X86_WRMSR_EXIT 0x21
#define HV_X86_VCPU_READ_APIC_TRAP 0x22
#define HV_X86_VCPU_READ_VMCS_TRAP 0x23
#define HV_X86_VCPU_RUN_TRAP 0x24
#define HV_X86_VCPU_RUN_UNTIL_TRAP 0x25
#define HV_X86_VCPU_WRITE_APIC_TRAP 0x26
#define HV_X86_VM_ADDRSPACE_CREATE_TRAP 0x27
#define HV_X86_VM_ADDRSPACE_DESTROY_TRAP 0x28
#define HV_X86_VM_INTR_MSI_TRAP 0x29
#define HV_X86_VM_MAP_TRAP 0x2a
#define HV_X86_VM_PROTECT_TRAP 0x2b
#define HV_X86_VM_UNMAP_TRAP 0x2c
#define HV_X86_TSC_OFFSET_SET 0x2d
#define VM_RECLAIM_UPDATE_ACCOUNTING 0x01
#define VM_RECLAIM_ENTRIES 0x02
#define VM_RECLAIM_CHUNK 0x03
#define VM_RECLAIM_ENTRY 0x04
#define VM_RECLAIM_ALL_MEMORY 0x05
#define VM_RECLAIM_ASYNC_MEMORY 0x06
#define VM_RECLAIM_INIT 0x07
#define DBG_NETIP 1
#define DBG_NETARP 2
#define DBG_NETUDP 3
#define DBG_NETTCP 4
#define DBG_NETICMP 5
#define DBG_NETIGMP 6
#define DBG_NETRIP 7
#define DBG_NETOSPF 8
#define DBG_NETISIS 9
#define DBG_NETSNMP 10
#define DBG_NETSOCK 11
#define DBG_NETAARP 100
#define DBG_NETDDP 101
#define DBG_NETNBP 102
#define DBG_NETZIP 103
#define DBG_NETADSP 104
#define DBG_NETATP 105
#define DBG_NETASP 106
#define DBG_NETAFP 107
#define DBG_NETRTMP 108
#define DBG_NETAURP 109
#define DBG_NETIPSEC 128
#define DBG_NETVMNET 129
#define DBG_IOINTC 0
#define DBG_IOWORKLOOP 1
#define DBG_IOINTES 2
#define DBG_IOCLKES 3
#define DBG_IOCMDQ 4
#define DBG_IOMCURS 5
#define DBG_IOMDESC 6
#define DBG_IOPOWER 7
#define DBG_IOSERVICE 8
#define DBG_IOREGISTRY 9
#define DBG_IOPORT 10
#define DBG_IOSTORAGE 32
#define DBG_IONETWORK 33
#define DBG_IOKEYBOARD 34
#define DBG_IOHID 35
#define DBG_IOAUDIO 36
#define DBG_IOSERIAL 37
#define DBG_IOTTY 38
#define DBG_IOSAM 39
#define DBG_IOPARALLELATA 40
#define DBG_IOPARALLELSCSI 41
#define DBG_IOSATA 42
#define DBG_IOSAS 43
#define DBG_IOFIBRECHANNEL 44
#define DBG_IOUSB 45
#define DBG_IOBLUETOOTH 46
#define DBG_IOFIREWIRE 47
#define DBG_IOINFINIBAND 48
#define DBG_IOCPUPM 49
#define DBG_IOGRAPHICS 50
#define DBG_HIBERNATE 51
#define DBG_IOTHUNDERBOLT 52
#define DBG_BOOTER 53
#define DBG_IOAUDIO2 54
#define DBG_IOAFK 55
#define DBG_IOSURFACEPA 64
#define DBG_IOMDPA 65
#define DBG_IODARTPA 66
#define DBG_DRVSTORAGE 1
#define DBG_DRVNETWORK 2
#define DBG_DRVKEYBOARD 3
#define DBG_DRVHID 4
#define DBG_DRVAUDIO 5
#define DBG_DRVSERIAL 7
#define DBG_DRVSAM 8
#define DBG_DRVPARALLELATA 9
#define DBG_DRVPARALLELSCSI 10
#define DBG_DRVSATA 11
#define DBG_DRVSAS 12
#define DBG_DRVFIBRECHANNEL 13
#define DBG_DRVUSB 14
#define DBG_DRVBLUETOOTH 15
#define DBG_DRVFIREWIRE 16
#define DBG_DRVINFINIBAND 17
#define DBG_DRVGRAPHICS 18
#define DBG_DRVSD 19
#define DBG_DRVNAND 20
#define DBG_SSD 21
#define DBG_DRVSPI 22
#define DBG_DRVWLAN_802_11 23
#define DBG_DRVSSM 24
#define DBG_DRVSMC 25
#define DBG_DRVMACEFIMANAGER 26
#define DBG_DRVANE 27
#define DBG_DRVETHERNET 28
#define DBG_DRVMCC 29
#define DBG_DRVACCESSORY 30
#define DBG_SOCDIAGS 31
#define DBG_DRVVIRTIO 32
#define DBG_DRVCELLULAR 33
#define DBG_DRVSPMI 34
#define DBG_DLIL_STATIC 1
#define DBG_DLIL_PR_MOD 2
#define DBG_DLIL_IF_MOD 3
#define DBG_DLIL_PR_FLT 4
#define DBG_DLIL_IF_FLT 5
#define DBG_FSRW 0x1
#define DBG_DKRW 0x2
#define DBG_FSVN 0x3
#define DBG_FSLOOOKUP 0x4
#define DBG_JOURNAL 0x5
#define DBG_IOCTL 0x6
#define DBG_BOOTCACHE 0x7
#define DBG_HFS 0x8
#define DBG_APFS 0x9
#define DBG_SMB 0xA
#define DBG_MOUNT 0xB
#define DBG_EXFAT 0xE
#define DBG_MSDOS 0xF
#define DBG_ACFS 0x10
#define DBG_THROTTLE 0x11
#define DBG_DECMP 0x12
#define DBG_VFS 0x13
#define DBG_LIVEFS 0x14
#define DBG_NFS 0x15
#define DBG_CONTENT_PROT 0xCF
#define DBG_HFS_UPDATE_ACCTIME 0x01
#define DBG_HFS_UPDATE_MODTIME 0x02
#define DBG_HFS_UPDATE_CHGTIME 0x04
#define DBG_HFS_UPDATE_MODIFIED 0x08
#define DBG_HFS_UPDATE_FORCE 0x10
#define DBG_HFS_UPDATE_DATEADDED 0x20
#define DBG_HFS_UPDATE_MINOR 0x40
#define DBG_HFS_UPDATE_SKIPPED 0x80
#define DBG_VFS_IO_COMPRESSION_STATS 0x1000
#define DBG_BSD_PROC 0x01
#define DBG_BSD_MEMSTAT 0x02
#define DBG_BSD_KEVENT 0x03
#define DBG_BSD_EXCP_SC 0x0C
#define DBG_BSD_AIO 0x0D
#define DBG_BSD_SC_EXTENDED_INFO 0x0E
#define DBG_BSD_SC_EXTENDED_INFO2 0x0F
#define DBG_BSD_KDEBUG_TEST 0xFF
#define BSD_PROC_EXIT 1
#define BSD_PROC_FRCEXIT 2
#define BSD_PROC_EXEC 3
#define BSD_PROC_EXITREASON_CREATE 4
#define BSD_PROC_EXITREASON_COMMIT 5
#define BSD_MEMSTAT_SCAN 1
#define BSD_MEMSTAT_JETSAM 2
#define BSD_MEMSTAT_JETSAM_HIWAT 3
#define BSD_MEMSTAT_FREEZE 4
#define BSD_MEMSTAT_FREEZE_SCAN 5
#define BSD_MEMSTAT_UPDATE 6
#define BSD_MEMSTAT_IDLE_DEMOTE 7
#define BSD_MEMSTAT_CLEAR_ERRORS 8
#define BSD_MEMSTAT_DIRTY_TRACK 9
#define BSD_MEMSTAT_DIRTY_SET 10
#define BSD_MEMSTAT_DIRTY_CLEAR 11
#define BSD_MEMSTAT_FAST_JETSAM 15
#define BSD_MEMSTAT_COMPACTOR_RUN 16
#define BSD_MEMSTAT_FREEZE_DISABLE 17
#define BSD_MEMSTAT_RELAUNCH_FLAGS 18
#define BSD_KEVENT_KQ_PROCESS_BEGIN 1
#define BSD_KEVENT_KQ_PROCESS_END 2
#define BSD_KEVENT_KQWQ_PROCESS_BEGIN 3
#define BSD_KEVENT_KQWQ_PROCESS_END 4
#define BSD_KEVENT_KQWQ_BIND 5
#define BSD_KEVENT_KQWQ_UNBIND 6
#define BSD_KEVENT_KQWQ_THREQUEST 7
#define BSD_KEVENT_KQWL_PROCESS_BEGIN 8
#define BSD_KEVENT_KQWL_PROCESS_END 9
#define BSD_KEVENT_KQWL_THREQUEST 10
#define BSD_KEVENT_KQWL_THADJUST 11
#define BSD_KEVENT_KQ_REGISTER 12
#define BSD_KEVENT_KQWQ_REGISTER 13
#define BSD_KEVENT_KQWL_REGISTER 14
#define BSD_KEVENT_KNOTE_ACTIVATE 15
#define BSD_KEVENT_KQ_PROCESS 16
#define BSD_KEVENT_KQWQ_PROCESS 17
#define BSD_KEVENT_KQWL_PROCESS 18
#define BSD_KEVENT_KQWL_BIND 19
#define BSD_KEVENT_KQWL_UNBIND 20
#define BSD_KEVENT_KNOTE_ENABLE 21
#define BSD_KEVENT_KNOTE_VANISHED 22
#define DBG_TRACE_DATA 0
#define DBG_TRACE_STRING 1
#define DBG_TRACE_INFO 2
#define DBG_CS_IO 0
#define DBG_SEC_KERNEL 0
#define DBG_SEC_SANDBOX 1
#define DBG_MT_INSTRS_CYCLES 1
#define DBG_MT_DEBUG 2
#define DBG_MT_RESOURCES_PROC_EXIT 3
#define DBG_MT_RESOURCES_THR_EXIT 4
#define DBG_MT_INSTRS_CYCLES_ON_CPU 5
#define DBG_MT_TMPTH 0xfe
#define DBG_MT_TMPCPU 0xff
#define DBG_MISC_COREBRIGHTNESS 0x01
#define DBG_MISC_VIDEOENG 0x02
#define DBG_EVENT 0x10
#define DBG_MISC_INSTRUMENTS 0x11
#define DBG_MISC_INSTRUMENTSBT 0x12
#define DBG_MISC_RUNLOOP_DETAILS 0x13
#define DBG_MISC_RUNLOOP_BUSY 0x14
#define DBG_MISC_LAYOUT 0x1a
#define DBG_BUFFER 0x20
#define DKIO_DONE 0x01
#define DKIO_READ 0x02
#define DKIO_ASYNC 0x04
#define DKIO_META 0x08
#define DKIO_PAGING 0x10
#define DKIO_THROTTLE 0x20
#define DKIO_PASSIVE 0x40
#define DKIO_NOCACHE 0x80
#define DKIO_TIER_MASK 0xF00
#define DKIO_TIER_SHIFT 8
#define DKIO_TIER_UPGRADE 0x1000
#define DBG_APP_LOGINWINDOW 0x03
#define DBG_APP_AUDIO 0x04
#define DBG_APP_SYSTEMUI 0x05
#define DBG_APP_SIGNPOST 0x0A
#define DBG_APP_TAL 0x0B
#define DBG_APP_APPKIT 0x0C
#define DBG_APP_UIKIT 0x0D
#define DBG_APP_DFR 0x0E
#define DBG_APP_LAYOUT 0x0F
#define DBG_APP_COREDATA 0x10
#define DBG_APP_RUNLOOP_BASIC 0x11
#define DBG_APP_RUNLOOP_ADVANCED 0x12
#define DBG_APP_SAMBA 0x80
#define DBG_APP_EOSSUPPORT 0x81
#define DBG_APP_MACEFIMANAGER 0x82
#define DBG_APP_ENTERPRISE 0x83
#define OPEN_THROTTLE_WINDOW 0x1
#define PROCESS_THROTTLED 0x2
#define IO_THROTTLE_DISABLE 0x3
#define IO_TIER_UPL_MISMATCH 0x4
#define IMP_ASSERTION 0x10
#define IMP_BOOST 0x11
#define IMP_MSG 0x12
#define IMP_WATCHPORT 0x13
#define IMP_TASK_SUPPRESSION 0x17
#define IMP_TASK_APPTYPE 0x18
#define IMP_UPDATE 0x19
#define IMP_USYNCH_QOS_OVERRIDE 0x1A
#define IMP_DONOR_CHANGE 0x1B
#define IMP_MAIN_THREAD_QOS 0x1C
#define IMP_SYNC_IPC_QOS 0x1D
#define IMP_TASK_POLICY_DARWIN_BG 0x21
#define IMP_TASK_POLICY_IOPOL 0x22
#define IMP_TASK_POLICY_IO 0x23
#define IMP_TASK_POLICY_PASSIVE_IO 0x24
#define IMP_TASK_POLICY_DARWIN_BG_IOPOL 0x27
#define IMP_TASK_POLICY_BOOST 0x29
#define IMP_TASK_POLICY_ROLE 0x2A
#define IMP_TASK_POLICY_TERMINATED 0x2C
#define IMP_TASK_POLICY_NEW_SOCKETS_BG 0x2D
#define IMP_TASK_POLICY_SUP_ACTIVE 0x2E
#define IMP_TASK_POLICY_LATENCY_QOS 0x2F
#define IMP_TASK_POLICY_THROUGH_QOS 0x30
#define IMP_TASK_POLICY_WATCHERS_BG 0x31
#define IMP_TASK_POLICY_SFI_MANAGED 0x34
#define IMP_TASK_POLICY_ALL_SOCKETS_BG 0x37
#define IMP_TASK_POLICY_BASE_LATENCY_AND_THROUGHPUT_QOS 0x39
#define IMP_TASK_POLICY_OVERRIDE_LATENCY_AND_THROUGHPUT_QOS 0x3A
#define IMP_TASK_POLICY_PIDBIND_BG 0x32
#define IMP_TASK_POLICY_QOS_OVERRIDE 0x36
#define IMP_TASK_POLICY_QOS_AND_RELPRIO 0x38
#define IMP_TASK_POLICY_QOS_WORKQ_OVERRIDE 0x3B
#define IMP_TASK_POLICY_QOS_PROMOTE 0x3C
#define IMP_TASK_POLICY_QOS_KEVENT_OVERRIDE 0x3D
#define IMP_TASK_POLICY_QOS_SERVICER_OVERRIDE 0x3E
#define IMP_TASK_POLICY_IOTIER_KEVENT_OVERRIDE 0x3F
#define IMP_TASK_POLICY_WI_DRIVEN 0x40
#define IMP_HOLD 0x2
#define IMP_DROP 0x4
#define IMP_EXTERN 0x8
#define IMP_BOOSTED 0x1
#define IMP_UNBOOSTED 0x2
#define IMP_MSG_SEND 0x1
#define IMP_MSG_DELV 0x2
#define IMP_UPDATE_TASK_CREATE 0x1
#define IMP_USYNCH_ADD_OVERRIDE 0x0
#define IMP_USYNCH_REMOVE_OVERRIDE 0x1
#define IMP_DONOR_UPDATE_LIVE_DONOR_STATE 0x0
#define IMP_DONOR_INIT_DONOR_STATE 0x1
#define IMP_SYNC_IPC_QOS_APPLIED 0x0
#define IMP_SYNC_IPC_QOS_REMOVED 0x1
#define IMP_SYNC_IPC_QOS_OVERFLOW 0x2
#define IMP_SYNC_IPC_QOS_UNDERFLOW 0x3
#define TURNSTILE_HEAP_OPERATIONS 0x10
#define TURNSTILE_PRIORITY_OPERATIONS 0x20
#define TURNSTILE_FREELIST_OPERATIONS 0x30
#define THREAD_ADDED_TO_TURNSTILE_WAITQ 0x1
#define THREAD_REMOVED_FROM_TURNSTILE_WAITQ 0x2
#define THREAD_MOVED_IN_TURNSTILE_WAITQ 0x3
#define TURNSTILE_ADDED_TO_TURNSTILE_HEAP 0x4
#define TURNSTILE_REMOVED_FROM_TURNSTILE_HEAP 0x5
#define TURNSTILE_MOVED_IN_TURNSTILE_HEAP 0x6
#define TURNSTILE_ADDED_TO_THREAD_HEAP 0x7
#define TURNSTILE_REMOVED_FROM_THREAD_HEAP 0x8
#define TURNSTILE_MOVED_IN_THREAD_HEAP 0x9
#define TURNSTILE_UPDATE_STOPPED_BY_LIMIT 0xa
#define THREAD_NOT_WAITING_ON_TURNSTILE 0xb
#define TURNSTILE_PRIORITY_CHANGE 0x1
#define THREAD_USER_PROMOTION_CHANGE 0x2
#define TURNSTILE_PREPARE 0x1
#define TURNSTILE_COMPLETE 0x2
#define BANK_ACCOUNT_INFO 0x10
#define BANK_TASK_INFO 0x11
#define ATM_SUBAID_INFO 0x10
#define ATM_GETVALUE_INFO 0x20
#define ATM_UNREGISTER_INFO 0x30
#define BANK_SETTLE_CPU_TIME 0x1
#define BANK_SECURE_ORIGINATOR_CHANGED 0x2
#define BANK_SETTLE_ENERGY 0x3
#define ATM_MIN_CALLED 0x1
#define ATM_LINK_LIST_TRIM 0x2
#define ATM_VALUE_REPLACED 0x1
#define ATM_VALUE_ADDED 0x2
#define ATM_VALUE_UNREGISTERED 0x1
#define ATM_VALUE_DIFF_MAILBOX 0x2
#define DBG_DAEMON_COREDUET 0x1
#define DBG_DAEMON_POWERD 0x2
#define DBG_UMALLOC_EXTERNAL 0x1
#define DBG_UMALLOC_INTERNAL 0x2
#define BSD 199506
#define BSD4_3 1
#define BSD4_4 1
#define NeXTBSD 1995064
#define NeXTBSD4_0 0
#define MAXCOMLEN 16
#define MAXINTERP 64
#define MAXLOGNAME 255
#define NOFILE 256
#define NOGROUP 65535
#define MAXHOSTNAMELEN 256
#define MAXDOMNAMELEN 256
#define PSWP 0
#define PVM 4
#define PINOD 8
#define PRIBIO 16
#define PVFS 20
#define PZERO 22
#define PSOCK 24
#define PWAIT 32
#define PLOCK 36
#define PPAUSE 40
#define PUSER 50
#define MAXPRI 127
#define PRIMASK 0x0ff
#define PCATCH 0x100
#define PTTYBLOCK 0x200
#define PDROP 0x400
#define PSPIN 0x800
#define CMASK 0022
#define CBLOCK 64
#define MAXFRAG 8
#define MAXSYMLINKS 32
#define FSHIFT 11
#define LF_NOT_BOOSTED 0
#define LF_BOOSTED 1
#define PSHMNAMLEN 31
#define SHM_RDONLY 0010000
#define SHM_RND 0020000
#define SHMLBA 4096
#define TIOCM_LE 00001
#define TIOCM_DTR 00002
#define TIOCM_RTS 00004
#define TIOCM_ST 00010
#define TIOCM_SR 00020
#define TIOCM_CTS 00040
#define TIOCM_CAR 00100
#define TIOCM_RNG 00200
#define TIOCM_DSR 00400
#define TIOCPKT_DATA 0x00
#define TIOCPKT_FLUSHREAD 0x01
#define TIOCPKT_FLUSHWRITE 0x02
#define TIOCPKT_STOP 0x04
#define TIOCPKT_START 0x08
#define TIOCPKT_NOSTOP 0x10
#define TIOCPKT_DOSTOP 0x20
#define TIOCPKT_IOCTL 0x40
#define TTYDISC 0
#define TABLDISC 3
#define SLIPDISC 4
#define PPPDISC 5
#define CTL_MAXNAME 12
#define CTLTYPE 0xf
#define CTLTYPE_NODE 1
#define CTLTYPE_INT 2
#define CTLTYPE_STRING 3
#define CTLTYPE_QUAD 4
#define CTLTYPE_OPAQUE 5
#define CTLFLAG_RD 0x80000000
#define CTLFLAG_WR 0x40000000
#define CTLFLAG_NOLOCK 0x20000000
#define CTLFLAG_ANYBODY 0x10000000
#define CTLFLAG_SECURE 0x08000000
#define CTLFLAG_MASKED 0x04000000
#define CTLFLAG_NOAUTO 0x02000000
#define CTLFLAG_KERN 0x01000000
#define CTLFLAG_LOCKED 0x00800000
#define CTLFLAG_OID2 0x00400000
#define CTLFLAG_EXPERIMENT 0x00100000
#define OID_AUTO_START 100
#define SYSCTL_OID_VERSION 1
#define SYSCTL_SKMEM 1
#define CTL_UNSPEC 0
#define CTL_KERN 1
#define CTL_VM 2
#define CTL_VFS 3
#define CTL_NET 4
#define CTL_DEBUG 5
#define CTL_HW 6
#define CTL_MACHDEP 7
#define CTL_USER 8
#define CTL_MAXID 9
#define KERN_OSTYPE 1
#define KERN_OSRELEASE 2
#define KERN_OSREV 3
#define KERN_VERSION 4
#define KERN_MAXVNODES 5
#define KERN_MAXPROC 6
#define KERN_MAXFILES 7
#define KERN_ARGMAX 8
#define KERN_SECURELVL 9
#define KERN_HOSTNAME 10
#define KERN_HOSTID 11
#define KERN_CLOCKRATE 12
#define KERN_VNODE 13
#define KERN_PROC 14
#define KERN_FILE 15
#define KERN_PROF 16
#define KERN_POSIX1 17
#define KERN_NGROUPS 18
#define KERN_JOB_CONTROL 19
#define KERN_SAVED_IDS 20
#define KERN_BOOTTIME 21
#define KERN_NISDOMAINNAME 22
#define KERN_MAXPARTITIONS 23
#define KERN_KDEBUG 24
#define KERN_UPDATEINTERVAL 25
#define KERN_OSRELDATE 26
#define KERN_NTP_PLL 27
#define KERN_BOOTFILE 28
#define KERN_MAXFILESPERPROC 29
#define KERN_MAXPROCPERUID 30
#define KERN_DUMPDEV 31
#define KERN_IPC 32
#define KERN_DUMMY 33
#define KERN_PS_STRINGS 34
#define KERN_USRSTACK32 35
#define KERN_LOGSIGEXIT 36
#define KERN_SYMFILE 37
#define KERN_PROCARGS 38
#define KERN_NETBOOT 40
#define KERN_SYSV 42
#define KERN_AFFINITY 43
#define KERN_TRANSLATE 44
#define KERN_EXEC 45
#define KERN_AIOMAX 46
#define KERN_AIOPROCMAX 47
#define KERN_AIOTHREADS 48
#define KERN_PROCARGS2 49
#define KERN_COREFILE 50
#define KERN_COREDUMP 51
#define KERN_SUGID_COREDUMP 52
#define KERN_PROCDELAYTERM 53
#define KERN_SHREG_PRIVATIZABLE 54
#define KERN_LOW_PRI_WINDOW 56
#define KERN_LOW_PRI_DELAY 57
#define KERN_POSIX 58
#define KERN_USRSTACK64 59
#define KERN_NX_PROTECTION 60
#define KERN_TFP 61
#define KERN_PROCNAME 62
#define KERN_THALTSTACK 63
#define KERN_SPECULATIVE_READS 64
#define KERN_OSVERSION 65
#define KERN_SAFEBOOT 66
#define KERN_RAGEVNODE 68
#define KERN_TTY 69
#define KERN_CHECKOPENEVT 70
#define KERN_THREADNAME 71
#define KERN_MAXID 72
#define KERN_RAGE_PROC 1
#define KERN_RAGE_THREAD 2
#define KERN_UNRAGE_PROC 3
#define KERN_UNRAGE_THREAD 4
#define KERN_OPENEVT_PROC 1
#define KERN_UNOPENEVT_PROC 2
#define KERN_TFP_POLICY 1
#define KERN_TFP_POLICY_DENY 0
#define KERN_TFP_POLICY_DEFAULT 2
#define KERN_KDEFLAGS 1
#define KERN_KDDFLAGS 2
#define KERN_KDENABLE 3
#define KERN_KDSETBUF 4
#define KERN_KDGETBUF 5
#define KERN_KDSETUP 6
#define KERN_KDREMOVE 7
#define KERN_KDSETREG 8
#define KERN_KDGETREG 9
#define KERN_KDREADTR 10
#define KERN_KDPIDTR 11
#define KERN_KDTHRMAP 12
#define KERN_KDPIDEX 14
#define KERN_KDSETRTCDEC 15
#define KERN_KDGETENTROPY 16
#define KERN_KDWRITETR 17
#define KERN_KDWRITEMAP 18
#define KERN_KDTEST 19
#define KERN_KDREADCURTHRMAP 21
#define KERN_KDSET_TYPEFILTER 22
#define KERN_KDBUFWAIT 23
#define KERN_KDCPUMAP 24
#define KERN_KDCPUMAP_EXT 25
#define KERN_KDSET_EDM 26
#define KERN_KDGET_EDM 27
#define KERN_KDWRITETR_V3 28
#define KERN_PROC_ALL 0
#define KERN_PROC_PID 1
#define KERN_PROC_PGRP 2
#define KERN_PROC_SESSION 3
#define KERN_PROC_TTY 4
#define KERN_PROC_UID 5
#define KERN_PROC_RUID 6
#define KERN_PROC_LCID 7
#define KERN_VFSNSPACE_HANDLE_PROC 1
#define KERN_VFSNSPACE_UNHANDLE_PROC 2
#define KIPC_MAXSOCKBUF 1
#define KIPC_SOCKBUF_WASTE 2
#define KIPC_SOMAXCONN 3
#define KIPC_MAX_LINKHDR 4
#define KIPC_MAX_PROTOHDR 5
#define KIPC_MAX_HDR 6
#define KIPC_MAX_DATALEN 7
#define KIPC_MBSTAT 8
#define KIPC_NMBCLUSTERS 9
#define KIPC_SOQLIMITCOMPAT 10
#define VM_METER 1
#define VM_LOADAVG 2
#define VM_MACHFACTOR 4
#define VM_SWAPUSAGE 5
#define VM_MAXID 6
#define LSCALE 1000
#define HW_MACHINE 1
#define HW_MODEL 2
#define HW_NCPU 3
#define HW_BYTEORDER 4
#define HW_PHYSMEM 5
#define HW_USERMEM 6
#define HW_PAGESIZE 7
#define HW_DISKNAMES 8
#define HW_DISKSTATS 9
#define HW_EPOCH 10
#define HW_FLOATINGPT 11
#define HW_MACHINE_ARCH 12
#define HW_VECTORUNIT 13
#define HW_BUS_FREQ 14
#define HW_CPU_FREQ 15
#define HW_CACHELINE 16
#define HW_L1ICACHESIZE 17
#define HW_L1DCACHESIZE 18
#define HW_L2SETTINGS 19
#define HW_L2CACHESIZE 20
#define HW_L3SETTINGS 21
#define HW_L3CACHESIZE 22
#define HW_TB_FREQ 23
#define HW_MEMSIZE 24
#define HW_AVAILCPU 25
#define HW_TARGET 26
#define HW_PRODUCT 27
#define HW_MAXID 28
#define USER_CS_PATH 1
#define USER_BC_BASE_MAX 2
#define USER_BC_DIM_MAX 3
#define USER_BC_SCALE_MAX 4
#define USER_BC_STRING_MAX 5
#define USER_COLL_WEIGHTS_MAX 6
#define USER_EXPR_NEST_MAX 7
#define USER_LINE_MAX 8
#define USER_RE_DUP_MAX 9
#define USER_POSIX2_VERSION 10
#define USER_POSIX2_C_BIND 11
#define USER_POSIX2_C_DEV 12
#define USER_POSIX2_CHAR_TERM 13
#define USER_POSIX2_FORT_DEV 14
#define USER_POSIX2_FORT_RUN 15
#define USER_POSIX2_LOCALEDEF 16
#define USER_POSIX2_SW_DEV 17
#define USER_POSIX2_UPE 18
#define USER_STREAM_MAX 19
#define USER_TZNAME_MAX 20
#define USER_MAXID 21
#define CTL_DEBUG_NAME 0
#define CTL_DEBUG_VALUE 1
#define CTL_DEBUG_MAXID 20
#define UTF_REVERSE_ENDIAN 0x0001
#define UTF_NO_NULL_TERM 0x0002
#define UTF_DECOMPOSED 0x0004
#define UTF_PRECOMPOSED 0x0008
#define UTF_ESCAPE_ILLEGAL 0x0010
#define UTF_SFM_CONVERSIONS 0x0020
#define PRIO_PROCESS 0
#define PRIO_PGRP 1
#define PRIO_USER 2
#define PRIO_DARWIN_THREAD 3
#define PRIO_DARWIN_PROCESS 4
#define PRIO_MAX 20
#define PRIO_DARWIN_BG 0x1000
#define PRIO_DARWIN_NONUI 0x1001
#define RUSAGE_SELF 0
#define RUSAGE_INFO_V0 0
#define RUSAGE_INFO_V1 1
#define RUSAGE_INFO_V2 2
#define RUSAGE_INFO_V3 3
#define RUSAGE_INFO_V4 4
#define RUSAGE_INFO_V5 5
#define RUSAGE_INFO_V6 6
#define RU_PROC_RUNS_RESLIDE 0x00000001
#define RLIMIT_CPU 0
#define RLIMIT_FSIZE 1
#define RLIMIT_DATA 2
#define RLIMIT_STACK 3
#define RLIMIT_CORE 4
#define RLIMIT_AS 5
#define RLIMIT_MEMLOCK 6
#define RLIMIT_NPROC 7
#define RLIMIT_NOFILE 8
#define RLIM_NLIMITS 9
#define _RLIMIT_POSIX_FLAG 0x1000
#define RLIMIT_WAKEUPS_MONITOR 0x1
#define RLIMIT_CPU_USAGE_MONITOR 0x2
#define RLIMIT_THREAD_CPULIMITS 0x3
#define RLIMIT_FOOTPRINT_INTERVAL 0x4
#define WAKEMON_ENABLE 0x01
#define WAKEMON_DISABLE 0x02
#define WAKEMON_GET_PARAMS 0x04
#define WAKEMON_SET_DEFAULTS 0x08
#define WAKEMON_MAKE_FATAL 0x10
#define CPUMON_MAKE_FATAL 0x1000
#define FOOTPRINT_INTERVAL_RESET 0x1
#define IOPOL_TYPE_DISK 0
#define IOPOL_TYPE_VFS_ATIME_UPDATES 2
#define IOPOL_TYPE_VFS_MATERIALIZE_DATALESS_FILES 3
#define IOPOL_TYPE_VFS_STATFS_NO_DATA_VOLUME 4
#define IOPOL_TYPE_VFS_TRIGGER_RESOLVE 5
#define IOPOL_TYPE_VFS_IGNORE_CONTENT_PROTECTION 6
#define IOPOL_TYPE_VFS_IGNORE_PERMISSIONS 7
#define IOPOL_TYPE_VFS_SKIP_MTIME_UPDATE 8
#define IOPOL_TYPE_VFS_ALLOW_LOW_SPACE_WRITES 9
#define IOPOL_TYPE_VFS_DISALLOW_RW_FOR_O_EVTONLY 10
#define IOPOL_SCOPE_PROCESS 0
#define IOPOL_SCOPE_THREAD 1
#define IOPOL_SCOPE_DARWIN_BG 2
#define IOPOL_DEFAULT 0
#define IOPOL_IMPORTANT 1
#define IOPOL_PASSIVE 2
#define IOPOL_THROTTLE 3
#define IOPOL_UTILITY 4
#define IOPOL_STANDARD 5
#define IOPOL_ATIME_UPDATES_DEFAULT 0
#define IOPOL_ATIME_UPDATES_OFF 1
#define IOPOL_MATERIALIZE_DATALESS_FILES_DEFAULT 0
#define IOPOL_MATERIALIZE_DATALESS_FILES_OFF 1
#define IOPOL_MATERIALIZE_DATALESS_FILES_ON 2
#define IOPOL_VFS_STATFS_NO_DATA_VOLUME_DEFAULT 0
#define IOPOL_VFS_STATFS_FORCE_NO_DATA_VOLUME 1
#define IOPOL_VFS_TRIGGER_RESOLVE_DEFAULT 0
#define IOPOL_VFS_TRIGGER_RESOLVE_OFF 1
#define IOPOL_VFS_CONTENT_PROTECTION_DEFAULT 0
#define IOPOL_VFS_CONTENT_PROTECTION_IGNORE 1
#define IOPOL_VFS_IGNORE_PERMISSIONS_OFF 0
#define IOPOL_VFS_IGNORE_PERMISSIONS_ON 1
#define IOPOL_VFS_SKIP_MTIME_UPDATE_OFF 0
#define IOPOL_VFS_SKIP_MTIME_UPDATE_ON 1
#define IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_OFF 0
#define IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_ON 1
#define IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_DEFAULT 0
#define IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_ON 1
#define IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_DEFAULT 0
#define IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_ON 1
#define IOCPARM_MASK 0x1fff
#define XATTR_NOFOLLOW 0x0001
#define XATTR_CREATE 0x0002
#define XATTR_REPLACE 0x0004
#define XATTR_NOSECURITY 0x0008
#define XATTR_NODEFAULT 0x0010
#define XATTR_SHOWCOMPRESSION 0x0020
#define XATTR_NOFOLLOW_ANY 0x0040
#define XATTR_MAXNAMELEN 127
#define PR_SLOWHZ 2
#define PRC_IFDOWN 0
#define PRC_ROUTEDEAD 1
#define PRC_IFUP 2
#define PRC_QUENCH2 3
#define PRC_QUENCH 4
#define PRC_MSGSIZE 5
#define PRC_HOSTDEAD 6
#define PRC_HOSTUNREACH 7
#define PRC_UNREACH_NET 8
#define PRC_UNREACH_HOST 9
#define PRC_UNREACH_PROTOCOL 10
#define PRC_UNREACH_PORT 11
#define PRC_UNREACH_SRCFAIL 13
#define PRC_REDIRECT_NET 14
#define PRC_REDIRECT_HOST 15
#define PRC_REDIRECT_TOSNET 16
#define PRC_REDIRECT_TOSHOST 17
#define PRC_TIMXCEED_INTRANS 18
#define PRC_TIMXCEED_REASS 19
#define PRC_PARAMPROB 20
#define PRC_UNREACH_ADMIN_PROHIB 21
#define PRC_NCMDS 22
#define KEV_CTL_SUBCLASS 2
#define KEV_CTL_REGISTERED 1
#define KEV_CTL_DEREGISTERED 2
#define MAX_KCTL_NAME 96
#define CTL_FLAG_PRIVILEGED 0x1
#define CTL_FLAG_REG_ID_UNIT 0x2
#define CTL_FLAG_REG_SOCK_STREAM 0x4
#define CTL_DATA_NOWAKEUP 0x1
#define CTL_DATA_EOR 0x2
#define __has_safe_buffers 0
#define __DARWIN_ONLY_64_BIT_INO_T 0
#define __DARWIN_ONLY_UNIX_CONFORMANCE 0
#define __DARWIN_ONLY_VERS_1050 0
#define __STDC_WANT_LIB_EXT1__ 1
#define __DARWIN_NO_LONG_LONG 0
#define _DARWIN_FEATURE_64_BIT_INODE 1
#define _DARWIN_FEATURE_ONLY_64_BIT_INODE 1
#define _DARWIN_FEATURE_ONLY_VERS_1050 1
#define _DARWIN_FEATURE_ONLY_UNIX_CONFORMANCE 1
#define _DARWIN_FEATURE_UNIX_CONFORMANCE 3
#define __has_ptrcheck 0
#define MAXMAXPARTITIONS 22
#define NDDATA 5
#define NSPARE 5
#define DTYPE_SMD 1
#define DTYPE_MSCP 2
#define DTYPE_DEC 3
#define DTYPE_SCSI 4
#define DTYPE_ESDI 5
#define DTYPE_ST506 6
#define DTYPE_HPIB 7
#define DTYPE_HPFL 8
#define DTYPE_FLOPPY 10
#define FS_UNUSED 0
#define FS_SWAP 1
#define FS_V6 2
#define FS_V7 3
#define FS_SYSV 4
#define FS_V71K 5
#define FS_V8 6
#define FS_BSDFFS 7
#define FS_MSDOS 8
#define FS_BSDLFS 9
#define FS_OTHER 10
#define FS_HPFS 11
#define FS_ISO9660 12
#define FS_BOOT 13
#define FS_ADOS 14
#define FS_HFS 15
#define D_REMOVABLE 0x01
#define D_ECC 0x02
#define D_BADSECT 0x04
#define D_RAMDISK 0x08
#define D_CHAIN 0x10
#define D_SSE 0x1
#define EPERM 1
#define ENOENT 2
#define ESRCH 3
#define EINTR 4
#define EIO 5
#define ENXIO 6
#define E2BIG 7
#define ENOEXEC 8
#define EBADF 9
#define ECHILD 10
#define EDEADLK 11
#define ENOMEM 12
#define EACCES 13
#define EFAULT 14
#define ENOTBLK 15
#define EBUSY 16
#define EEXIST 17
#define EXDEV 18
#define ENODEV 19
#define ENOTDIR 20
#define EISDIR 21
#define EINVAL 22
#define ENFILE 23
#define EMFILE 24
#define ENOTTY 25
#define ETXTBSY 26
#define EFBIG 27
#define ENOSPC 28
#define ESPIPE 29
#define EROFS 30
#define EMLINK 31
#define EPIPE 32
#define EDOM 33
#define ERANGE 34
#define EAGAIN 35
#define EINPROGRESS 36
#define EALREADY 37
#define ENOTSOCK 38
#define EDESTADDRREQ 39
#define EMSGSIZE 40
#define EPROTOTYPE 41
#define ENOPROTOOPT 42
#define EPROTONOSUPPORT 43
#define ESOCKTNOSUPPORT 44
#define ENOTSUP 45
#define EPFNOSUPPORT 46
#define EAFNOSUPPORT 47
#define EADDRINUSE 48
#define EADDRNOTAVAIL 49
#define ENETDOWN 50
#define ENETUNREACH 51
#define ENETRESET 52
#define ECONNABORTED 53
#define ECONNRESET 54
#define ENOBUFS 55
#define EISCONN 56
#define ENOTCONN 57
#define ESHUTDOWN 58
#define ETOOMANYREFS 59
#define ETIMEDOUT 60
#define ECONNREFUSED 61
#define ELOOP 62
#define ENAMETOOLONG 63
#define EHOSTDOWN 64
#define EHOSTUNREACH 65
#define ENOTEMPTY 66
#define EPROCLIM 67
#define EUSERS 68
#define EDQUOT 69
#define ESTALE 70
#define EREMOTE 71
#define EBADRPC 72
#define ERPCMISMATCH 73
#define EPROGUNAVAIL 74
#define EPROGMISMATCH 75
#define EPROCUNAVAIL 76
#define ENOLCK 77
#define ENOSYS 78
#define EFTYPE 79
#define EAUTH 80
#define ENEEDAUTH 81
#define EPWROFF 82
#define EDEVERR 83
#define EOVERFLOW 84
#define EBADEXEC 85
#define EBADARCH 86
#define ESHLIBVERS 87
#define EBADMACHO 88
#define ECANCELED 89
#define EIDRM 90
#define ENOMSG 91
#define EILSEQ 92
#define ENOATTR 93
#define EBADMSG 94
#define EMULTIHOP 95
#define ENODATA 96
#define ENOLINK 97
#define ENOSR 98
#define ENOSTR 99
#define EPROTO 100
#define ETIME 101
#define EOPNOTSUPP 102
#define ENOPOLICY 103
#define ENOTRECOVERABLE 104
#define EOWNERDEAD 105
#define EQFULL 106
#define ELAST 106
#define VEOF 0
#define VEOL 1
#define VEOL2 2
#define VERASE 3
#define VWERASE 4
#define VKILL 5
#define VREPRINT 6
#define VINTR 8
#define VQUIT 9
#define VSUSP 10
#define VDSUSP 11
#define VSTART 12
#define VSTOP 13
#define VLNEXT 14
#define VDISCARD 15
#define VMIN 16
#define VTIME 17
#define VSTATUS 18
#define NCCS 20
#define IGNBRK 0x00000001
#define BRKINT 0x00000002
#define IGNPAR 0x00000004
#define PARMRK 0x00000008
#define INPCK 0x00000010
#define ISTRIP 0x00000020
#define INLCR 0x00000040
#define IGNCR 0x00000080
#define ICRNL 0x00000100
#define IXON 0x00000200
#define IXOFF 0x00000400
#define IXANY 0x00000800
#define IMAXBEL 0x00002000
#define IUTF8 0x00004000
#define OPOST 0x00000001
#define ONLCR 0x00000002
#define OXTABS 0x00000004
#define ONOEOT 0x00000008
#define OCRNL 0x00000010
#define ONOCR 0x00000020
#define ONLRET 0x00000040
#define OFILL 0x00000080
#define NLDLY 0x00000300
#define TABDLY 0x00000c04
#define CRDLY 0x00003000
#define FFDLY 0x00004000
#define BSDLY 0x00008000
#define VTDLY 0x00010000
#define OFDEL 0x00020000
#define TAB3 0x00000004
#define VT0 0x00000000
#define VT1 0x00010000
#define CIGNORE 0x00000001
#define CSIZE 0x00000300
#define CS5 0x00000000
#define CS6 0x00000100
#define CS7 0x00000200
#define CS8 0x00000300
#define CSTOPB 0x00000400
#define CREAD 0x00000800
#define PARENB 0x00001000
#define PARODD 0x00002000
#define HUPCL 0x00004000
#define CLOCAL 0x00008000
#define CCTS_OFLOW 0x00010000
#define CRTS_IFLOW 0x00020000
#define CDTR_IFLOW 0x00040000
#define CDSR_OFLOW 0x00080000
#define CCAR_OFLOW 0x00100000
#define ECHOKE 0x00000001
#define ECHOE 0x00000002
#define ECHOK 0x00000004
#define ECHONL 0x00000010
#define ECHOPRT 0x00000020
#define ECHOCTL 0x00000040
#define ISIG 0x00000080
#define ICANON 0x00000100
#define ALTWERASE 0x00000200
#define IEXTEN 0x00000400
#define EXTPROC 0x00000800
#define NOKERNINFO 0x02000000
#define TCSANOW 0
#define TCSADRAIN 1
#define TCSAFLUSH 2
#define TCSASOFT 0x10
#define B0 0
#define B50 50
#define B75 75
#define B110 110
#define B134 134
#define B150 150
#define B200 200
#define B300 300
#define B600 600
#define B1200 1200
#define B1800 1800
#define B2400 2400
#define B4800 4800
#define B9600 9600
#define B19200 19200
#define B38400 38400
#define B7200 7200
#define B14400 14400
#define B28800 28800
#define B57600 57600
#define B76800 76800
#define B115200 115200
#define B230400 230400
#define EXTA 19200
#define EXTB 38400
#define RENAME_SECLUDE 0x00000001
#define RENAME_SWAP 0x00000002
#define RENAME_EXCL 0x00000004
#define RENAME_RESERVED1 0x00000008
#define RENAME_NOFOLLOW_ANY 0x00000010
#define MFSNAMELEN 15
#define MFSTYPENAMELEN 16
#define MNAMELEN 90
#define MNT_EXT_ROOT_DATA_VOL 0x00000001
#define MNT_EXT_FSKIT 0x00000002
#define MNT_RDONLY 0x00000001
#define MNT_SYNCHRONOUS 0x00000002
#define MNT_NOEXEC 0x00000004
#define MNT_NOSUID 0x00000008
#define MNT_NODEV 0x00000010
#define MNT_UNION 0x00000020
#define MNT_ASYNC 0x00000040
#define MNT_CPROTECT 0x00000080
#define MNT_EXPORTED 0x00000100
#define MNT_REMOVABLE 0x00000200
#define MNT_QUARANTINE 0x00000400
#define MNT_LOCAL 0x00001000
#define MNT_QUOTA 0x00002000
#define MNT_ROOTFS 0x00004000
#define MNT_DOVOLFS 0x00008000
#define MNT_DONTBROWSE 0x00100000
#define MNT_IGNORE_OWNERSHIP 0x00200000
#define MNT_AUTOMOUNTED 0x00400000
#define MNT_JOURNALED 0x00800000
#define MNT_NOUSERXATTR 0x01000000
#define MNT_DEFWRITE 0x02000000
#define MNT_MULTILABEL 0x04000000
#define MNT_NOFOLLOW 0x08000000
#define MNT_NOATIME 0x10000000
#define MNT_SNAPSHOT 0x40000000
#define MNT_STRICTATIME 0x80000000
#define MNT_UPDATE 0x00010000
#define MNT_NOBLOCK 0x00020000
#define MNT_RELOAD 0x00040000
#define MNT_FORCE 0x00080000
#define VFS_GENERIC 0
#define VFS_NUMMNTOPS 1
#define VFS_MAXTYPENUM 1
#define VFS_CONF 2
#define MNT_WAIT 1
#define MNT_NOWAIT 2
#define MNT_DWAIT 4
#define MNT_VOLUME 8
#define VFS_CTL_VERS1 0x01
#define VFS_CTL_OSTATFS 0x00010001
#define VFS_CTL_UMOUNT 0x00010002
#define VFS_CTL_QUERY 0x00010003
#define VFS_CTL_NEWADDR 0x00010004
#define VFS_CTL_TIMEO 0x00010005
#define VFS_CTL_NOLOCKS 0x00010006
#define VFS_CTL_SADDR 0x00010007
#define VFS_CTL_DISC 0x00010008
#define VFS_CTL_SERVERINFO 0x00010009
#define VFS_CTL_NSTATUS 0x0001000A
#define VFS_CTL_STATFS64 0x0001000B
#define VQ_NOTRESP 0x0001
#define VQ_NEEDAUTH 0x0002
#define VQ_LOWDISK 0x0004
#define VQ_MOUNT 0x0008
#define VQ_UNMOUNT 0x0010
#define VQ_DEAD 0x0020
#define VQ_ASSIST 0x0040
#define VQ_NOTRESPLOCK 0x0080
#define VQ_UPDATE 0x0100
#define VQ_VERYLOWDISK 0x0200
#define VQ_SYNCEVENT 0x0400
#define VQ_SERVEREVENT 0x0800
#define VQ_QUOTA 0x1000
#define VQ_NEARLOWDISK 0x2000
#define VQ_DESIRED_DISK 0x4000
#define VQ_FREE_SPACE_CHANGE 0x8000
#define VQ_PURGEABLE_SPACE_CHANGE 0x10000
#define VQ_FLAG20000 0x20000
#define VFS_IOATTR_FLAGS_FUA 0x00000001
#define VFS_IOATTR_FLAGS_UNMAP 0x00000002
#define VFS_IOATTR_FLAGS_SWAPPIN_SUPPORTED 0x00000010
#define VFS_TBLTHREADSAFE 0x0001
#define VFS_TBLFSNODELOCK 0x0002
#define VFS_TBLNOTYPENUM 0x0008
#define VFS_TBLLOCALVOL 0x0010
#define VFS_TBL64BITREADY 0x0020
#define VFS_TBLNATIVEXATTR 0x0040
#define VFS_TBLDIRLINKS 0x0080
#define VFS_TBLUNMOUNT_PREFLIGHT 0x0100
#define VFS_TBLGENERICMNTARGS 0x0200
#define VFS_TBLREADDIR_EXTENDED 0x0400
#define VFS_TBLNOMACLABEL 0x1000
#define VFS_TBLVNOP_PAGEINV2 0x2000
#define VFS_TBLVNOP_PAGEOUTV2 0x4000
#define VFS_TBLVNOP_NOUPDATEID_RENAME 0x8000
#define VFS_TBLVNOP_SECLUDE_RENAME 0x10000
#define VFS_TBLCANMOUNTROOT 0x20000
#define VFSIOC_MOUNT_BYROLE_has_recovery 1
#define VFS_RETURNED 0
#define VFS_RETURNED_DONE 1
#define VFS_CLAIMED 2
#define VFS_CLAIMED_DONE 3
#define VFS_USER_EVENT 0
#define VFS_KERNEL_EVENT 1
#define LK_NOWAIT 1
#define NFSV4_MAX_FH_SIZE 128
#define NFSV3_MAX_FH_SIZE 64
#define NFSV2_MAX_FH_SIZE 32
#define CRYPTEX_AUTH_STRUCT_VERSION 2
#define EV_FD 1
#define EV_RE 1
#define EV_WR 2
#define EV_EX 4
#define EV_RM 8
#define EV_MASK 0xf
#define EV_RBYTES 0x100
#define EV_WBYTES 0x200
#define EV_RCLOSED 0x400
#define EV_RCONN 0x800
#define EV_WCLOSED 0x1000
#define EV_WCONN 0x2000
#define EV_OOB 0x4000
#define EV_FIN 0x8000
#define EV_RESET 0x10000
#define EV_TIMEOUT 0x20000
#define EV_DMASK 0xffffff00
#define KDEBUG_LEVEL_NONE 0
#define KDEBUG_LEVEL_IST 1
#define KDEBUG_LEVEL_STANDARD 2
#define KDEBUG_LEVEL_FULL 3
#define KDBG_FLAG_FILTERED 0x01
#define KDBG_FLAG_NOPROCFILT 0x02
#define __DARWIN_LITTLE_ENDIAN 1234
#define __DARWIN_BIG_ENDIAN 4321
#define __DARWIN_PDP_ENDIAN 3412
#define USE_CLANG_TYPES 0
#define __DARWIN_NULL 0
#define UBC_PUSHDIRTY 0x01
#define UBC_PUSHALL 0x02
#define UBC_INVALIDATE 0x04
#define UBC_SYNC 0x08
#define KAUTH_NTSID_MAX_AUTHORITIES 16
#define KAUTH_EXTLOOKUP_SUCCESS 0
#define KAUTH_EXTLOOKUP_BADRQ 1
#define KAUTH_EXTLOOKUP_FAILURE 2
#define KAUTH_EXTLOOKUP_FATAL 3
#define KAUTH_EXTLOOKUP_INPROG 100
#define KAUTH_ACE_KINDMASK 0xf
#define KAUTH_ACE_PERMIT 1
#define KAUTH_ACE_DENY 2
#define KAUTH_ACE_AUDIT 3
#define KAUTH_ACE_ALARM 4
#define KAUTH_ACL_MAX_ENTRIES 128
#define KAUTH_FILESEC_MAGIC 0x012cc16d
#define KAUTH_ENDIAN_HOST 0x00000001
#define KAUTH_ENDIAN_DISK 0x00000002
#define KAUTH_GENERIC_ISSUSER 1
#define KAUTH_PROCESS_CANSIGNAL 1
#define KAUTH_PROCESS_CANTRACE 2
#define KAUTH_FILEOP_OPEN 1
#define KAUTH_FILEOP_CLOSE 2
#define KAUTH_FILEOP_RENAME 3
#define KAUTH_FILEOP_EXCHANGE 4
#define KAUTH_FILEOP_LINK 5
#define KAUTH_FILEOP_EXEC 6
#define KAUTH_FILEOP_DELETE 7
#define KAUTH_FILEOP_WILL_RENAME 8
#define DBG_PPT 36
#define DBG_PERFCTRL 39
#define DBG_CLPC 50
#define DBG_MUSE 52
#define DBG_ANS 128
#define DBG_SIO 129
#define DBG_SEP 130
#define DBG_ISP 131
#define DBG_OSCAR 132
#define DBG_EMBEDDEDGFX 133
#define DBG_PMP 134
#define DBG_RTKIT 135
#define DBG_DCP 136
#define DBG_KMP 137
#define DBG_SKYWALK_ALWAYSON 0x10
#define DBG_SKYWALK_FLOWSWITCH 0x11
#define DBG_SKYWALK_NETIF 0x12
#define DBG_SKYWALK_CHANNEL 0x13
#define DBG_SKYWALK_PACKET 0x14
#define DBG_AQM_ALWAYSON 0x30
#define DBG_AQM_STATS 0x31
#define PPT_TEST 0x01
#define PPT_JETSAM_HIWAT 0x02
#define PPT_JETSAM_TOPPROC 0x03
#define DBG_SEC_SSMA 0x02
#define KDBG_CPU_SHIFT 56
#define KDBG_INIT 0x01
#define KDBG_FREERUN 0x04
#define KDBG_CPUMAP_IS_IOP 0x1
#define KDEBUG_COMMPAGE_ENABLE_TRACE 0x1
#define KDEBUG_COMMPAGE_ENABLE_TYPEFILTER 0x2
#define KDEBUG_COMMPAGE_CONTINUOUS 0x4
#define KDBG_LOCKINIT 0x0080
#define KDBG_CLASSTYPE 0x10000
#define KDBG_SUBCLSTYPE 0x20000
#define KDBG_RANGETYPE 0x40000
#define KDBG_TYPENONE 0x80000
#define KDBG_CKTYPES 0xF0000
#define RAW_VERSION0 0x55aa0000
#define RAW_VERSION1 0x55aa0101
#define RAW_VERSION2 0x55aa0200
#define kEnTrCompKernel 2
#define kEnTrActKernSocket 1
#define kEnTrActKernSockRead 2
#define kEnTrActKernSockWrite 3
#define kEnTrActKernPoll 10
#define kEnTrActKernSelect 11
#define kEnTrActKernKQWait 12
#define kEnTrEvUnblocked 256
#define kEnTrFlagNonBlocking 0x1
#define kEnTrFlagNoWork 0x2
#define ENTR_SHOULDTRACE 0
#define SYS_syscall 0
#define SYS_exit 1
#define SYS_fork 2
#define SYS_read 3
#define SYS_write 4
#define SYS_open 5
#define SYS_close 6
#define SYS_wait4 7
#define SYS_link 9
#define SYS_unlink 10
#define SYS_chdir 12
#define SYS_fchdir 13
#define SYS_mknod 14
#define SYS_chmod 15
#define SYS_chown 16
#define SYS_getfsstat 18
#define SYS_getpid 20
#define SYS_setuid 23
#define SYS_getuid 24
#define SYS_geteuid 25
#define SYS_ptrace 26
#define SYS_recvmsg 27
#define SYS_sendmsg 28
#define SYS_recvfrom 29
#define SYS_accept 30
#define SYS_getpeername 31
#define SYS_getsockname 32
#define SYS_access 33
#define SYS_chflags 34
#define SYS_fchflags 35
#define SYS_sync 36
#define SYS_kill 37
#define SYS_crossarch_trap 38
#define SYS_getppid 39
#define SYS_dup 41
#define SYS_pipe 42
#define SYS_getegid 43
#define SYS_sigaction 46
#define SYS_getgid 47
#define SYS_sigprocmask 48
#define SYS_getlogin 49
#define SYS_setlogin 50
#define SYS_acct 51
#define SYS_sigpending 52
#define SYS_sigaltstack 53
#define SYS_ioctl 54
#define SYS_reboot 55
#define SYS_revoke 56
#define SYS_symlink 57
#define SYS_readlink 58
#define SYS_execve 59
#define SYS_umask 60
#define SYS_chroot 61
#define SYS_msync 65
#define SYS_vfork 66
#define SYS_munmap 73
#define SYS_mprotect 74
#define SYS_madvise 75
#define SYS_mincore 78
#define SYS_getgroups 79
#define SYS_setgroups 80
#define SYS_getpgrp 81
#define SYS_setpgid 82
#define SYS_setitimer 83
#define SYS_swapon 85
#define SYS_getitimer 86
#define SYS_getdtablesize 89
#define SYS_dup2 90
#define SYS_fcntl 92
#define SYS_select 93
#define SYS_fsync 95
#define SYS_setpriority 96
#define SYS_socket 97
#define SYS_connect 98
#define SYS_getpriority 100
#define SYS_bind 104
#define SYS_setsockopt 105
#define SYS_listen 106
#define SYS_sigsuspend 111
#define SYS_gettimeofday 116
#define SYS_getrusage 117
#define SYS_getsockopt 118
#define SYS_readv 120
#define SYS_writev 121
#define SYS_settimeofday 122
#define SYS_fchown 123
#define SYS_fchmod 124
#define SYS_setreuid 126
#define SYS_setregid 127
#define SYS_rename 128
#define SYS_flock 131
#define SYS_mkfifo 132
#define SYS_sendto 133
#define SYS_shutdown 134
#define SYS_socketpair 135
#define SYS_mkdir 136
#define SYS_rmdir 137
#define SYS_utimes 138
#define SYS_futimes 139
#define SYS_adjtime 140
#define SYS_gethostuuid 142
#define SYS_setsid 147
#define SYS_getpgid 151
#define SYS_setprivexec 152
#define SYS_pread 153
#define SYS_pwrite 154
#define SYS_nfssvc 155
#define SYS_statfs 157
#define SYS_fstatfs 158
#define SYS_unmount 159
#define SYS_getfh 161
#define SYS_quotactl 165
#define SYS_mount 167
#define SYS_csops 169
#define SYS_csops_audittoken 170
#define SYS_waitid 173
#define SYS_kdebug_typefilter 177
#define SYS_kdebug_trace_string 178
#define SYS_kdebug_trace64 179
#define SYS_kdebug_trace 180
#define SYS_setgid 181
#define SYS_setegid 182
#define SYS_seteuid 183
#define SYS_sigreturn 184
#define SYS_panic_with_data 185
#define SYS_thread_selfcounts 186
#define SYS_fdatasync 187
#define SYS_stat 188
#define SYS_fstat 189
#define SYS_lstat 190
#define SYS_pathconf 191
#define SYS_fpathconf 192
#define SYS_getrlimit 194
#define SYS_setrlimit 195
#define SYS_getdirentries 196
#define SYS_mmap 197
#define SYS_lseek 199
#define SYS_truncate 200
#define SYS_ftruncate 201
#define SYS_sysctl 202
#define SYS_mlock 203
#define SYS_munlock 204
#define SYS_undelete 205
#define SYS_open_dprotected_np 216
#define SYS_fsgetpath_ext 217
#define SYS_openat_dprotected_np 218
#define SYS_getattrlist 220
#define SYS_setattrlist 221
#define SYS_getdirentriesattr 222
#define SYS_exchangedata 223
#define SYS_searchfs 225
#define SYS_delete 226
#define SYS_copyfile 227
#define SYS_fgetattrlist 228
#define SYS_fsetattrlist 229
#define SYS_poll 230
#define SYS_getxattr 234
#define SYS_fgetxattr 235
#define SYS_setxattr 236
#define SYS_fsetxattr 237
#define SYS_removexattr 238
#define SYS_fremovexattr 239
#define SYS_listxattr 240
#define SYS_flistxattr 241
#define SYS_fsctl 242
#define SYS_initgroups 243
#define SYS_posix_spawn 244
#define SYS_ffsctl 245
#define SYS_fhopen 248
#define SYS_minherit 250
#define SYS_semsys 251
#define SYS_msgsys 252
#define SYS_shmsys 253
#define SYS_semctl 254
#define SYS_semget 255
#define SYS_semop 256
#define SYS_msgctl 258
#define SYS_msgget 259
#define SYS_msgsnd 260
#define SYS_msgrcv 261
#define SYS_shmat 262
#define SYS_shmctl 263
#define SYS_shmdt 264
#define SYS_shmget 265
#define SYS_shm_open 266
#define SYS_shm_unlink 267
#define SYS_sem_open 268
#define SYS_sem_close 269
#define SYS_sem_unlink 270
#define SYS_sem_wait 271
#define SYS_sem_trywait 272
#define SYS_sem_post 273
#define SYS_sysctlbyname 274
#define SYS_open_extended 277
#define SYS_umask_extended 278
#define SYS_stat_extended 279
#define SYS_lstat_extended 280
#define SYS_fstat_extended 281
#define SYS_chmod_extended 282
#define SYS_fchmod_extended 283
#define SYS_access_extended 284
#define SYS_settid 285
#define SYS_gettid 286
#define SYS_setsgroups 287
#define SYS_getsgroups 288
#define SYS_setwgroups 289
#define SYS_getwgroups 290
#define SYS_mkfifo_extended 291
#define SYS_mkdir_extended 292
#define SYS_identitysvc 293
#define SYS_shared_region_check_np 294
#define SYS_vm_pressure_monitor 296
#define SYS_psynch_rw_longrdlock 297
#define SYS_psynch_rw_yieldwrlock 298
#define SYS_psynch_rw_downgrade 299
#define SYS_psynch_rw_upgrade 300
#define SYS_psynch_mutexwait 301
#define SYS_psynch_mutexdrop 302
#define SYS_psynch_cvbroad 303
#define SYS_psynch_cvsignal 304
#define SYS_psynch_cvwait 305
#define SYS_psynch_rw_rdlock 306
#define SYS_psynch_rw_wrlock 307
#define SYS_psynch_rw_unlock 308
#define SYS_psynch_rw_unlock2 309
#define SYS_getsid 310
#define SYS_settid_with_pid 311
#define SYS_psynch_cvclrprepost 312
#define SYS_aio_fsync 313
#define SYS_aio_return 314
#define SYS_aio_suspend 315
#define SYS_aio_cancel 316
#define SYS_aio_error 317
#define SYS_aio_read 318
#define SYS_aio_write 319
#define SYS_lio_listio 320
#define SYS_iopolicysys 322
#define SYS_process_policy 323
#define SYS_mlockall 324
#define SYS_munlockall 325
#define SYS_issetugid 327
#define SYS___pthread_kill 328
#define SYS___pthread_sigmask 329
#define SYS___sigwait 330
#define SYS___disable_threadsignal 331
#define SYS___pthread_markcancel 332
#define SYS___pthread_canceled 333
#define SYS___semwait_signal 334
#define SYS_proc_info 336
#define SYS_sendfile 337
#define SYS_stat64 338
#define SYS_fstat64 339
#define SYS_lstat64 340
#define SYS_stat64_extended 341
#define SYS_lstat64_extended 342
#define SYS_fstat64_extended 343
#define SYS_getdirentries64 344
#define SYS_statfs64 345
#define SYS_fstatfs64 346
#define SYS_getfsstat64 347
#define SYS___pthread_chdir 348
#define SYS___pthread_fchdir 349
#define SYS_audit 350
#define SYS_auditon 351
#define SYS_getauid 353
#define SYS_setauid 354
#define SYS_getaudit_addr 357
#define SYS_setaudit_addr 358
#define SYS_auditctl 359
#define SYS_bsdthread_create 360
#define SYS_bsdthread_terminate 361
#define SYS_kqueue 362
#define SYS_kevent 363
#define SYS_lchown 364
#define SYS_bsdthread_register 366
#define SYS_workq_open 367
#define SYS_workq_kernreturn 368
#define SYS_kevent64 369
#define SYS_thread_selfid 372
#define SYS_ledger 373
#define SYS_kevent_qos 374
#define SYS_kevent_id 375
#define SYS___mac_execve 380
#define SYS___mac_syscall 381
#define SYS___mac_get_file 382
#define SYS___mac_set_file 383
#define SYS___mac_get_link 384
#define SYS___mac_set_link 385
#define SYS___mac_get_proc 386
#define SYS___mac_set_proc 387
#define SYS___mac_get_fd 388
#define SYS___mac_set_fd 389
#define SYS___mac_get_pid 390
#define SYS_pselect 394
#define SYS_pselect_nocancel 395
#define SYS_read_nocancel 396
#define SYS_write_nocancel 397
#define SYS_open_nocancel 398
#define SYS_close_nocancel 399
#define SYS_wait4_nocancel 400
#define SYS_recvmsg_nocancel 401
#define SYS_sendmsg_nocancel 402
#define SYS_recvfrom_nocancel 403
#define SYS_accept_nocancel 404
#define SYS_msync_nocancel 405
#define SYS_fcntl_nocancel 406
#define SYS_select_nocancel 407
#define SYS_fsync_nocancel 408
#define SYS_connect_nocancel 409
#define SYS_sigsuspend_nocancel 410
#define SYS_readv_nocancel 411
#define SYS_writev_nocancel 412
#define SYS_sendto_nocancel 413
#define SYS_pread_nocancel 414
#define SYS_pwrite_nocancel 415
#define SYS_waitid_nocancel 416
#define SYS_poll_nocancel 417
#define SYS_msgsnd_nocancel 418
#define SYS_msgrcv_nocancel 419
#define SYS_sem_wait_nocancel 420
#define SYS_aio_suspend_nocancel 421
#define SYS___sigwait_nocancel 422
#define SYS___semwait_signal_nocancel 423
#define SYS___mac_mount 424
#define SYS___mac_get_mount 425
#define SYS___mac_getfsstat 426
#define SYS_fsgetpath 427
#define SYS_audit_session_self 428
#define SYS_audit_session_join 429
#define SYS_fileport_makeport 430
#define SYS_fileport_makefd 431
#define SYS_audit_session_port 432
#define SYS_pid_suspend 433
#define SYS_pid_resume 434
#define SYS_pid_hibernate 435
#define SYS_pid_shutdown_sockets 436
#define SYS_kas_info 439
#define SYS_memorystatus_control 440
#define SYS_guarded_open_np 441
#define SYS_guarded_close_np 442
#define SYS_guarded_kqueue_np 443
#define SYS_change_fdguard_np 444
#define SYS_usrctl 445
#define SYS_proc_rlimit_control 446
#define SYS_connectx 447
#define SYS_disconnectx 448
#define SYS_peeloff 449
#define SYS_socket_delegate 450
#define SYS_telemetry 451
#define SYS_proc_uuid_policy 452
#define SYS_memorystatus_get_level 453
#define SYS_system_override 454
#define SYS_vfs_purge 455
#define SYS_sfi_ctl 456
#define SYS_sfi_pidctl 457
#define SYS_coalition 458
#define SYS_coalition_info 459
#define SYS_necp_match_policy 460
#define SYS_getattrlistbulk 461
#define SYS_clonefileat 462
#define SYS_openat 463
#define SYS_openat_nocancel 464
#define SYS_renameat 465
#define SYS_faccessat 466
#define SYS_fchmodat 467
#define SYS_fchownat 468
#define SYS_fstatat 469
#define SYS_fstatat64 470
#define SYS_linkat 471
#define SYS_unlinkat 472
#define SYS_readlinkat 473
#define SYS_symlinkat 474
#define SYS_mkdirat 475
#define SYS_getattrlistat 476
#define SYS_proc_trace_log 477
#define SYS_bsdthread_ctl 478
#define SYS_openbyid_np 479
#define SYS_recvmsg_x 480
#define SYS_sendmsg_x 481
#define SYS_thread_selfusage 482
#define SYS_csrctl 483
#define SYS_guarded_open_dprotected_np 484
#define SYS_guarded_write_np 485
#define SYS_guarded_pwrite_np 486
#define SYS_guarded_writev_np 487
#define SYS_renameatx_np 488
#define SYS_mremap_encrypted 489
#define SYS_netagent_trigger 490
#define SYS_stack_snapshot_with_config 491
#define SYS_microstackshot 492
#define SYS_grab_pgo_data 493
#define SYS_persona 494
#define SYS_mach_eventlink_signal 496
#define SYS_mach_eventlink_wait_until 497
#define SYS_mach_eventlink_signal_wait_until 498
#define SYS_work_interval_ctl 499
#define SYS_getentropy 500
#define SYS_necp_open 501
#define SYS_necp_client_action 502
#define SYS___nexus_open 503
#define SYS___nexus_register 504
#define SYS___nexus_deregister 505
#define SYS___nexus_create 506
#define SYS___nexus_destroy 507
#define SYS___nexus_get_opt 508
#define SYS___nexus_set_opt 509
#define SYS___channel_open 510
#define SYS___channel_get_info 511
#define SYS___channel_sync 512
#define SYS___channel_get_opt 513
#define SYS___channel_set_opt 514
#define SYS_ulock_wait 515
#define SYS_ulock_wake 516
#define SYS_fclonefileat 517
#define SYS_fs_snapshot 518
#define SYS_register_uexc_handler 519
#define SYS_terminate_with_payload 520
#define SYS_abort_with_payload 521
#define SYS_necp_session_open 522
#define SYS_necp_session_action 523
#define SYS_setattrlistat 524
#define SYS_net_qos_guideline 525
#define SYS_fmount 526
#define SYS_ntp_adjtime 527
#define SYS_ntp_gettime 528
#define SYS_os_fault_with_payload 529
#define SYS_kqueue_workloop_ctl 530
#define SYS___mach_bridge_remote_time 531
#define SYS_coalition_ledger 532
#define SYS_log_data 533
#define SYS_memorystatus_available_memory 534
#define SYS_objc_bp_assist_cfg_np 535
#define SYS_shared_region_map_and_slide_2_np 536
#define SYS_pivot_root 537
#define SYS_task_inspect_for_pid 538
#define SYS_task_read_for_pid 539
#define SYS_preadv 540
#define SYS_pwritev 541
#define SYS_preadv_nocancel 542
#define SYS_pwritev_nocancel 543
#define SYS_ulock_wait2 544
#define SYS_proc_info_extended_id 545
#define SYS_tracker_action 546
#define SYS_debug_syscall_reject 547
#define SYS_debug_syscall_reject_config 548
#define SYS_graftdmg 549
#define SYS_map_with_linking_np 550
#define SYS_freadlink 551
#define SYS_record_system_event 552
#define SYS_mkfifoat 553
#define SYS_mknodat 554
#define SYS_ungraftdmg 555
#define SYS_coalition_policy_set 556
#define SYS_coalition_policy_get 557
#define SYS_MAXSYSCALL 558
#define SYS_invalid 63
#define SOCK_STREAM 1
#define SOCK_DGRAM 2
#define SOCK_RAW 3
#define SOCK_RDM 4
#define SOCK_SEQPACKET 5
#define SO_DEBUG 0x0001
#define SO_ACCEPTCONN 0x0002
#define SO_REUSEADDR 0x0004
#define SO_KEEPALIVE 0x0008
#define SO_DONTROUTE 0x0010
#define SO_BROADCAST 0x0020
#define SO_USELOOPBACK 0x0040
#define SO_LINGER 0x1080
#define SO_LINGER_SEC 0x1080
#define SO_OOBINLINE 0x0100
#define SO_REUSEPORT 0x0200
#define SO_TIMESTAMP 0x0400
#define SO_TIMESTAMP_MONOTONIC 0x0800
#define SO_ACCEPTFILTER 0x1000
#define SO_DONTTRUNC 0x2000
#define SO_WANTMORE 0x4000
#define SO_WANTOOBFLAG 0x8000
#define SO_SNDBUF 0x1001
#define SO_RCVBUF 0x1002
#define SO_SNDLOWAT 0x1003
#define SO_RCVLOWAT 0x1004
#define SO_SNDTIMEO 0x1005
#define SO_RCVTIMEO 0x1006
#define SO_ERROR 0x1007
#define SO_TYPE 0x1008
#define SO_LABEL 0x1010
#define SO_PEERLABEL 0x1011
#define SO_NREAD 0x1020
#define SO_NKE 0x1021
#define SO_NOSIGPIPE 0x1022
#define SO_NOADDRERR 0x1023
#define SO_NWRITE 0x1024
#define SO_REUSESHAREUID 0x1025
#define SO_NOTIFYCONFLICT 0x1026
#define SO_UPCALLCLOSEWAIT 0x1027
#define SO_RANDOMPORT 0x1082
#define SO_NP_EXTENSIONS 0x1083
#define SO_NUMRCVPKT 0x1112
#define SO_NET_SERVICE_TYPE 0x1116
#define SO_NETSVC_MARKING_LEVEL 0x1119
#define SO_RESOLVER_SIGNATURE 0x1131
#define SO_BINDTODEVICE 0x1134
#define NET_SERVICE_TYPE_BE 0
#define NET_SERVICE_TYPE_BK 1
#define NET_SERVICE_TYPE_SIG 2
#define NET_SERVICE_TYPE_VI 3
#define NET_SERVICE_TYPE_VO 4
#define NET_SERVICE_TYPE_RV 5
#define NET_SERVICE_TYPE_AV 6
#define NET_SERVICE_TYPE_OAM 7
#define NET_SERVICE_TYPE_RD 8
#define NETSVC_MRKNG_UNKNOWN 0
#define NETSVC_MRKNG_LVL_L2 1
#define NETSVC_MRKNG_LVL_L3L2_ALL 2
#define NETSVC_MRKNG_LVL_L3L2_BK 3
#define SAE_ASSOCID_ANY 0
#define SAE_CONNID_ANY 0
#define CONNECT_RESUME_ON_READ_WRITE 0x1
#define CONNECT_DATA_IDEMPOTENT 0x2
#define CONNECT_DATA_AUTHENTICATED 0x4
#define SONPX_SETOPTSHUT 0x000000001
#define SOL_SOCKET 0xffff
#define AF_UNSPEC 0
#define AF_UNIX 1
#define AF_INET 2
#define AF_IMPLINK 3
#define AF_PUP 4
#define AF_CHAOS 5
#define AF_NS 6
#define AF_ISO 7
#define AF_ECMA 8
#define AF_DATAKIT 9
#define AF_CCITT 10
#define AF_SNA 11
#define AF_DECnet 12
#define AF_DLI 13
#define AF_LAT 14
#define AF_HYLINK 15
#define AF_APPLETALK 16
#define AF_ROUTE 17
#define AF_LINK 18
#define pseudo_AF_XTP 19
#define AF_COIP 20
#define AF_CNT 21
#define pseudo_AF_RTIP 22
#define AF_IPX 23
#define AF_SIP 24
#define pseudo_AF_PIP 25
#define AF_NDRV 27
#define AF_ISDN 28
#define pseudo_AF_KEY 29
#define AF_INET6 30
#define AF_NATM 31
#define AF_SYSTEM 32
#define AF_NETBIOS 33
#define AF_PPP 34
#define pseudo_AF_HDRCMPLT 35
#define AF_RESERVED_36 36
#define AF_IEEE80211 37
#define AF_UTUN 38
#define AF_VSOCK 40
#define AF_MAX 41
#define SOCK_MAXADDRLEN 255
#define _SS_MAXSIZE 128
#define NET_RT_DUMP 1
#define NET_RT_FLAGS 2
#define NET_RT_IFLIST 3
#define NET_RT_STAT 4
#define NET_RT_TRASH 5
#define NET_RT_IFLIST2 6
#define NET_RT_DUMP2 7
#define NET_RT_FLAGS_PRIV 10
#define NET_RT_MAXID 11
#define SOMAXCONN 128
#define MSG_OOB 0x1
#define MSG_PEEK 0x2
#define MSG_DONTROUTE 0x4
#define MSG_EOR 0x8
#define MSG_TRUNC 0x10
#define MSG_CTRUNC 0x20
#define MSG_WAITALL 0x40
#define MSG_DONTWAIT 0x80
#define MSG_EOF 0x100
#define MSG_WAITSTREAM 0x200
#define MSG_FLUSH 0x400
#define MSG_HOLD 0x800
#define MSG_SEND 0x1000
#define MSG_HAVEMORE 0x2000
#define MSG_RCVMORE 0x4000
#define MSG_NEEDSA 0x10000
#define MSG_NOSIGNAL 0x80000
#define MSG_USEUPCALL 0x80000000
#define CMGROUP_MAX 16
#define SCM_RIGHTS 0x01
#define SCM_TIMESTAMP 0x02
#define SCM_CREDS 0x03
#define SCM_TIMESTAMP_MONOTONIC 0x04
#define SHUT_RD 0
#define SHUT_WR 1
#define SHUT_RDWR 2
#define SBUF_FIXEDLEN 0x00000000
#define SBUF_AUTOEXTEND 0x00000001
#define SBUF_USRFLAGMSK 0x0000ffff
#define SBUF_DYNAMIC 0x00010000
#define SBUF_FINISHED 0x00020000
#define SBUF_OVERFLOWED 0x00040000
#define SBUF_DYNSTRUCT 0x00080000
#define SYSPROTO_EVENT 1
#define SYSPROTO_CONTROL 2
#define AF_SYS_CONTROL 2
#define SO_TRACKER_ATTRIBUTE_FLAGS_APP_APPROVED 0x00000001
#define SO_TRACKER_ATTRIBUTE_FLAGS_TRACKER 0x00000002
#define SO_TRACKER_ATTRIBUTE_FLAGS_DOMAIN_SHORT 0x00000004
#define NS_GETRAWENCRYPTED 0x00000001
